@@ -1,16 +1,39 @@
 /*
  * International Chemical Identifier (InChI)
  * Version 1
- * Software version 1.02-beta
- * August 23, 2007
- * Developed at NIST
+ * Software version 1.04
+ * September 9, 2011
  *
  * The InChI library and programs are free software developed under the
- * auspices of the International Union of Pure and Applied Chemistry (IUPAC);
- * you can redistribute this software and/or modify it under the terms of 
- * the GNU Lesser General Public License as published by the Free Software 
- * Foundation:
- * http://www.opensource.org/licenses/lgpl-license.php
+ * auspices of the International Union of Pure and Applied Chemistry (IUPAC).
+ * Originally developed at NIST. Modifications and additions by IUPAC 
+ * and the InChI Trust.
+ *
+ * IUPAC/InChI-Trust Licence for the International Chemical Identifier (InChI) 
+ * Software version 1.0.
+ * Copyright (C) IUPAC and InChI Trust Limited
+ * 
+ * This library is free software; you can redistribute it and/or modify it under the 
+ * terms of the IUPAC/InChI Trust Licence for the International Chemical Identifier 
+ * (InChI) Software version 1.0; either version 1.0 of the License, or 
+ * (at your option) any later version.
+ * 
+ * This library is distributed in the hope that it will be useful, 
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+ * See the IUPAC/InChI Trust Licence for the International Chemical Identifier (InChI) 
+ * Software version 1.0 for more details.
+ * 
+ * You should have received a copy of the IUPAC/InChI Trust Licence for the 
+ * International Chemical Identifier (InChI) Software version 1.0 along with 
+ * this library; if not, write to:
+ * 
+ * The InChI Trust
+ * c/o FIZ CHEMIE Berlin
+ * Franklinstrasse 11
+ * 10587 Berlin
+ * GERMANY
+ * 
  */
 
 
@@ -35,6 +58,10 @@
 #define REQ_MODE_SB_IGN_ALL_UU      0x001000    /* IAUSC Ignore stereobonds if All Undef/Unknown */
 #define REQ_MODE_CHIR_FLG_STEREO    0x002000    /* SUCF  If Chiral flag then Abs otherwise Rel stereo */
 /* end of 10-10-2003 */
+
+/*^^^ 2009-12-05 */
+#define REQ_MODE_DIFF_UU_STEREO     0x004000    /* SLUUD Make labels for unknown and undefined stereo different */
+/*^^^ 2009-12-05 */
 #define REQ_MODE_MIN_SB_RING_MASK   0x0F0000    /* RSB  */
 #define REQ_MODE_MIN_SB_RING_SHFT      16
 
@@ -108,6 +135,22 @@ typedef struct tagINChI_Stereo { /* [N] = allocated length */
 #define INCHI_OUT_SDFILE_ATOMS_DT       0x0800   /* SDfile output H isotopes as D and T */
 #define INCHI_OUT_SDFILE_SPLIT          0x1000   /* Split SDfile into components */
 
+#define INCHI_OUT_FIX_TRANSPOSITION_CHARGE_BUG 0x2000   
+                                    /* used to accomodate FIX_TRANSPOSITION_CHARGE_BUG */
+
+#define INCHI_OUT_STDINCHI 0x4000   
+#define INCHI_OUT_SAVEOPT  0x8000   
+
+
+/* Bits encoding InChI creation options to be saved */
+#define SAVE_OPT_SLUUD  0x0001
+#define SAVE_OPT_SUU    0x0002
+#define SAVE_OPT_FIXEDH 0x0004
+#define SAVE_OPT_RECMET 0x0008
+#define SAVE_OPT_KET    0x0010
+#define SAVE_OPT_15T    0x0020
+
+
 #define INCHI_OUT_PRINT_OPTIONS       (INCHI_OUT_EMBED_REC |           \
                                        INCHI_OUT_XML |                 \
                                        INCHI_OUT_PLAIN_TEXT |          \
@@ -155,13 +198,13 @@ typedef struct tagINChI {  /* [N] = allocated length */
                                                 /* not including mobile H groups */
     AT_NUMB *nPossibleLocationsOfIsotopicH;     /* [0]=> length including 0th element, location1,...*/
     int      bDeleted;
-#if( bREUSE_INCHI == 1 )
+#if ( bREUSE_INCHI == 1 )
     int nRefCount;
 #endif
-#if( bRELEASE_VERSION == 0 )
+#if ( bRELEASE_VERSION == 0 )
     int bExtract;
 #endif
-#if( READ_INCHI_STRING == 1 )
+#if ( READ_INCHI_STRING == 1 )
     int nLink;  /* negative: ignore InChI; positive: index of (Reconnected component) + 1 linked to it */
 #endif
 } INChI;
@@ -192,10 +235,10 @@ typedef struct tagINChI_Aux { /* [N] = allocated length */
     AT_NUMB   *nConstitEquTGroupNumbers;         /* [nNumberOfAtoms/2] */
     AT_NUMB   *nConstitEquIsotopicNumbers;       /* [nNumberOfAtoms*1.5] */
     AT_NUMB   *nConstitEquIsotopicTGroupNumbers; /* [nNumberOfAtoms/2] */
-#if( bREUSE_INCHI == 1 )
+#if ( bREUSE_INCHI == 1 )
     int nRefCount;
 #endif
-#if( TEST_RENUMB_ATOMS == 1 )
+#if ( TEST_RENUMB_ATOMS == 1 )
     unsigned long ulNormTime;
     unsigned long ulCanonTime;
 #endif
