@@ -1,16 +1,39 @@
 /*
  * International Chemical Identifier (InChI)
  * Version 1
- * Software version 1.02-beta
- * August 23, 2007
- * Developed at NIST
+ * Software version 1.04
+ * September 9, 2011
  *
  * The InChI library and programs are free software developed under the
- * auspices of the International Union of Pure and Applied Chemistry (IUPAC);
- * you can redistribute this software and/or modify it under the terms of 
- * the GNU Lesser General Public License as published by the Free Software 
- * Foundation:
- * http://www.opensource.org/licenses/lgpl-license.php
+ * auspices of the International Union of Pure and Applied Chemistry (IUPAC).
+ * Originally developed at NIST. Modifications and additions by IUPAC 
+ * and the InChI Trust.
+ *
+ * IUPAC/InChI-Trust Licence for the International Chemical Identifier (InChI) 
+ * Software version 1.0.
+ * Copyright (C) IUPAC and InChI Trust Limited
+ * 
+ * This library is free software; you can redistribute it and/or modify it under the 
+ * terms of the IUPAC/InChI Trust Licence for the International Chemical Identifier 
+ * (InChI) Software version 1.0; either version 1.0 of the License, or 
+ * (at your option) any later version.
+ * 
+ * This library is distributed in the hope that it will be useful, 
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+ * See the IUPAC/InChI Trust Licence for the International Chemical Identifier (InChI) 
+ * Software version 1.0 for more details.
+ * 
+ * You should have received a copy of the IUPAC/InChI Trust Licence for the 
+ * International Chemical Identifier (InChI) Software version 1.0 along with 
+ * this library; if not, write to:
+ * 
+ * The InChI Trust
+ * c/o FIZ CHEMIE Berlin
+ * Franklinstrasse 11
+ * 10587 Berlin
+ * GERMANY
+ * 
  */
 
 
@@ -77,7 +100,7 @@ typedef struct tagBfsQueue {
 #define EXTRACT_STRUCT_NUMBER 1
 
 /* additional Mobile-H parities to be added to Fixed-H parities  */
-/* This allows to set parities that exist in Mobile-H layer only */
+/* This allows one to set parities that exist in Mobile-H layer only */
 typedef struct tagInpAtomAddParities {
     /* cml 0D parities */
     S_CHAR        bUsed0DParity;          /* bit=1 => stereobond; bit=2 => stereocenter */
@@ -564,7 +587,7 @@ typedef struct tagStructCmpTwoMobileH {
 } CMP2MHINCHI;
 
 
-#ifndef INCHI_ALL_CPP
+#ifndef COMPILE_ALL_CPP
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -844,8 +867,11 @@ int AddRemIsoProtonsInRestrStruct( ICHICONST INPUT_PARMS *ip,  STRUCT_DATA *sd,
                                 StrFromINChI *pStruct, int num_components,
                                 StrFromINChI *pStructR, int num_componentsR,
                                 NUM_H pProtonBalance[], NUM_H recmet_change_balance[] );
-int OutputInChIOutOfStrFromINChI( ICHICONST INPUT_PARMS *ip_inp, STRUCT_DATA *sd_inp, long num_inp,
-                                  INCHI_FILE *pout, INCHI_FILE *plog, InpInChI *pOneInput, int bHasSomeFixedH );
+int OutputInChIOutOfStrFromINChI(ICHICONST INPUT_PARMS *ip_inp, STRUCT_DATA *sd_inp, 
+                                 long num_inp, int bINChIOutputOptions,
+                                 INCHI_IOSTREAM *pout, INCHI_IOSTREAM *plog, 
+                                 InpInChI *pOneInput, int bHasSomeFixedH,
+                                 unsigned char save_opt_bits);
 
 int MergeStructureComponents( ICHICONST INPUT_PARMS *ip, STRUCT_DATA *sd, long num_inp, char *szCurHdr,
                          ICHICONST SRM *pSrm, int bReqNonTaut, StrFromINChI *pStruct[INCHI_NUM][TAUT_NUM],
@@ -879,7 +905,7 @@ int MakeProtonComponent( StrFromINChI *pStruct, int iComponent, int num_prot );
 #define MOVE_CHARGES_FROM_HETEREO_TO_METAL   0  /* disabled */
 #define FIX_ADD_PROTON_FOR_ADP               0  /* not used */
 
-#ifndef INCHI_ALL_CPP
+#ifndef COMPILE_ALL_CPP
 #ifdef __cplusplus
 }
 #endif
