@@ -565,8 +565,8 @@ namespace OpenBabel
     double 	*_velocityPtr; //!< pointer to the velocities
     // contraint varibles
     static OBFFConstraints _constraints; //!< Constraints
-    static int _fixAtom; //!< SetFixAtom()/UnsetFixAtom()
-    static int _ignoreAtom; //!< SetIgnoreAtom()/UnsetIgnoreAtom()
+    static unsigned int _fixAtom; //!< SetFixAtom()/UnsetFixAtom()
+    static unsigned int _ignoreAtom; //!< SetIgnoreAtom()/UnsetIgnoreAtom()
     // cut-off variables
     bool 	_cutoff; //!< true = cut-off enabled
     double 	_rvdw; //!< VDW cut-off distance
@@ -1138,7 +1138,7 @@ namespace OpenBabel
 
     //! \name Methods for energy minimization
     //@{
-    /*! Set the LineSearchType. The default type is LineSearchType::Simple.
+    /*! Set the LineSearchType. The default type is LineSearchType::Newton2Num.
      *  \param type The LineSearchType to be used in SteepestDescent and ConjugateGradients.
      */
     void SetLineSearchType(int type)
