@@ -1,16 +1,16 @@
 /**********************************************************************
 obutil.h - Various utility methods.
- 
+
 Copyright (C) 1998-2001 by OpenEye Scientific Software, Inc.
 Some portions Copyright (C) 2001-2006 by Geoffrey R. Hutchison
- 
+
 This file is part of the Open Babel project.
-For more information, see <http://openbabel.sourceforge.net/>
- 
+For more information, see <http://openbabel.org/>
+
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation version 2 of the License.
- 
+
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -136,7 +136,7 @@ namespace OpenBabel
     //! \param incr The floating point resolution of the lookup table
     void Init(double max,double incr)
     {
-      // parameters are potentially unneeded, but let's do this until we can 
+      // parameters are potentially unneeded, but let's do this until we can
       // deprecate them
       _max = max * max;
       _incr = incr;
@@ -153,10 +153,17 @@ namespace OpenBabel
   };
 
   //***RMS helper methods***/
-#ifndef SWIG
-  OBAPI void  rotate_coords(double*,double m[3][3],int);
+#ifndef __KCC
+  extern "C" {
+  OBAPI void  rotate_coords(double*,double m[3][3],unsigned);
   OBAPI double calc_rms(double*,double*,unsigned int);
-
+  }
+#else
+  OBAPI void  rotate_coords(double*,double m[3][3],unsigned);
+  OBAPI double calc_rms(double*,double*,unsigned int);
+#endif
+ 
+#ifndef SWIG
   //! \name  String conversion utilities
   //@{
   // Documentation in obutil.cpp
@@ -222,19 +229,21 @@ namespace OpenBabel
   OBAPI inline bool IsApprox(const double & a, const double & b,
                              const double precision = 1e-11)
   {
-    return( fabs(a - b) <= precision * std::min( fabs(a), fabs(b) ) );
+    return( fabs(a - b) <= precision * std::min<const double>( fabs(a), fabs(b) ) );
   }
   //! Same as IsApprox(), but only for positive numbers. Faster.
   OBAPI inline bool IsApprox_pos(const double &a, const double &b,
                                  const double precision = 1e-11)
   {
-    return( fabs(a - b) <= precision * std::min( a, b ) );
+    return( fabs(a - b) <= precision * std::min<const double>( a, b ) );
   }
   /*! \brief Tests whether its argument can be squared without triggering
     an overflow or underflow.
   */
   OBAPI bool CanBeSquared(const double &);
 
+  OBAPI bool SafeOpen(std::ifstream &fs, const char *filename);
+  OBAPI bool SafeOpen(std::ofstream &fs, const char *filename);
 #endif
   // (end part to be skipped by SWIG)
 
@@ -253,7 +262,7 @@ namespace OpenBabel
       T1 first;
       T2 second;
       T3 third;
-  
+
       /** Default constructor
        *	T1() and T2() and T3() force initialization for built in types
        **/
