@@ -148,36 +148,75 @@ protected:
 //Macro to be added to definition of the base class
 #define MAKE_PLUGIN(BaseClass)\
 protected:\
-static PluginMapType& Map();\
-virtual PluginMapType& GetMap()const{return Map();}\
+  static PluginMapType& Map();\
+  virtual PluginMapType& GetMap() const {\
+    return Map();\
+  }\
 public:\
-static BaseClass*& Default(){static BaseClass* d;return d;}\
-  BaseClass(const char* ID, bool IsDefault=false)\
- {_id=ID;if(ID&&*ID){if(IsDefault || Map().empty()) Default() = this;\
- Map()[ID]=this;PluginMap()[TypeID()] =this;}}\
-static BaseClass* FindType(const char* ID)\
- {if(!ID || *ID==0 || *ID==' ') return Default();\
- return static_cast<BaseClass*>(BaseFindType(Map(),ID));}
+  static BaseClass*& Default() {\
+    static BaseClass* d;\
+    return d;\
+  }\
+  BaseClass(const char* ID, bool IsDefault=false) {\
+    _id=ID;\
+    if (ID&&*ID) {\
+      if (IsDefault || Map().empty()) {\
+        Default() = this;\
+      }\
+      if (Map().count(ID) == 0) {\
+        Map()[ID] = this;\
+        PluginMap()[TypeID()] = this;\
+      }\
+    }\
+  }\
+  static BaseClass* FindType(const char* ID) {\
+    if (!ID || *ID==0 || *ID==' ') {\
+      return Default();\
+    }\
+    return static_cast<BaseClass*>(BaseFindType(Map(),ID));\
+  }
 
 #define PLUGIN_CPP_FILE(BaseClass)\
-OBPlugin::PluginMapType& BaseClass::Map()\
-{ static OBPlugin::PluginMapType map; return map; }
+OBPlugin::PluginMapType& BaseClass::Map() {\
+  static OBPlugin::PluginMapType map;\
+  return map;\
+}
 
 #else // __CYGWIN__ || __MINGW32__
 
 //Macro to be added to definition of the base class
 #define MAKE_PLUGIN(BaseClass)\
 protected:\
-static PluginMapType& Map(){static PluginMapType m;return m;}\
-virtual PluginMapType& GetMap()const{return Map();}\
+  static PluginMapType& Map() {\
+    static PluginMapType m;\
+    return m;\
+  }\
+  virtual PluginMapType& GetMap() const {\
+    return Map();\
+  }\
 public:\
-static BaseClass*& Default(){static BaseClass* d;return d;}\
-  BaseClass(const char* ID, bool IsDefault=false)\
- {_id=ID;if(ID&&*ID){if(IsDefault || Map().empty()) Default() = this;\
- Map()[ID]=this;PluginMap()[TypeID()] =this;}}\
-static BaseClass* FindType(const char* ID)\
- {if(!ID || *ID==0 || *ID==' ') return Default();\
- return static_cast<BaseClass*>(BaseFindType(Map(),ID));}
+  static BaseClass*& Default() {\
+    static BaseClass* d;\
+    return d;\
+  }\
+  BaseClass(const char* ID, bool IsDefault=false) {\
+    _id=ID;\
+    if (ID&&*ID) {\
+      if (IsDefault || Map().empty()) {\
+        Default() = this;\
+      }\
+      if (Map().count(ID) == 0) {\
+        Map()[ID] = this;\
+        PluginMap()[TypeID()] = this;\
+      }\
+    }\
+  }\
+  static BaseClass* FindType(const char* ID) {\
+    if (!ID || *ID==0 || *ID==' ') {\
+      return Default();\
+    }\
+    return static_cast<BaseClass*>(BaseFindType(Map(),ID));\
+  }
 
 #endif // __CYGWIN__ || __MINGW32__
 
@@ -328,6 +367,8 @@ public:
   OBAPI EXTERN className instanceName;
 
   // formats
+  OB_STATIC_PLUGIN(AcesOutputFormat, theAcesOutputFormat)
+  OB_STATIC_PLUGIN(AcesInputFormat, theAcesInputFormat)
   OB_STATIC_PLUGIN(ACRFormat, theACRFormat)
   OB_STATIC_PLUGIN(ADFOutputFormat, theADFOutputFormat)
   OB_STATIC_PLUGIN(ADFInputFormat, theADFInputFormat)
