@@ -2,14 +2,14 @@
 reaction.h - Handle chemical reactions (i.e., lists of reagents and products).
 
 Copyright (C) 2005 by Chris Morley
- 
+
 This file is part of the Open Babel project.
-For more information, see <http://openbabel.sourceforge.net/>
- 
+For more information, see <http://openbabel.org/>
+
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation version 2 of the License.
- 
+
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -20,17 +20,9 @@ GNU General Public License for more details.
 #define OB_REACT_H
 
 #include <vector>
+#include <openbabel/shared_ptr.h>
 #include <openbabel/mol.h>
 
-#ifdef USE_BOOST
-  #include <boost/shared_ptr.hpp>
-  //namespace std{ namespace tr1=::boost; }
-  #define shared_ptr boost::shared_ptr
-#else
-  #include <tr1/memory>
-  #define shared_ptr std::tr1::shared_ptr
-#endif
-
 namespace OpenBabel
 {
 
@@ -45,8 +37,8 @@ class OBReaction : public OBBase
 private:
   std::vector<shared_ptr<OBMol> > _reactants;
   std::vector<shared_ptr<OBMol> > _products;
-  shared_ptr<OBMol> _ts; 
-  shared_ptr<OBMol> _agent; 
+  shared_ptr<OBMol> _ts;
+  shared_ptr<OBMol> _agent;
   std::string _title;
   std::string _comment;
   bool _reversible;
@@ -55,14 +47,14 @@ public:
   {}
 
   int NumReactants() const
-  { return _reactants.size(); }
+  { return static_cast<int> (_reactants.size()); }
 
   int NumProducts()const
-  { return _products.size(); }
-  
+  { return static_cast<int> (_products.size()); }
+
   void AddReactant(const shared_ptr<OBMol> sp)
   { _reactants.push_back(sp); }
-  
+
   void AddProduct(const shared_ptr<OBMol> sp)
   { _products.push_back(sp); }
 
@@ -71,7 +63,7 @@ public:
 
   void AddAgent(const shared_ptr<OBMol> sp)
   { _agent = sp; }
-  
+
   shared_ptr<OBMol> GetReactant(const unsigned i)
   {
     shared_ptr<OBMol> sp;
@@ -105,6 +97,18 @@ public:
   {
     return " reactions\n";
   }
+
+  bool Clear()
+  {
+    _reactants.clear();
+    _products.clear();
+    _ts.reset();
+    _agent.reset();
+    _title.clear();
+    _comment.clear();
+    _reversible = false;
+    return true;
+  }
 };
 
 
