@@ -4,7 +4,7 @@ optswx.h -  Constructs wxWidgets Option controls from description text
 Copyright (C) 2006 by Chris Morley
 
 This file is part of the Open Babel project.
-For more information, see <http://openbabel.sourceforge.net/>
+For more information, see <http://openbabel.org/>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -26,8 +26,8 @@ class DynOptionswx
 public:
 	typedef std::vector <std::pair<wxString, wxWindow*> > OMapType;
 
-	DynOptionswx :: DynOptionswx(wxWindow* Par, wxSizer* pSizer)
-		: parent(Par), sizer(pSizer){} 
+	DynOptionswx(wxWindow* Par, wxSizer* pSizer)
+		: parent(Par), sizer(pSizer){}
 	~DynOptionswx();
 	void Clear();
 	bool Construct(const char* OptionsText, const char* StartText=NULL, int MultiCharFilter=0);
