@@ -55,7 +55,7 @@ namespace OpenBabel
     \endcode
   */
 
-  static int bitsoff[SETWORD] =
+  static unsigned int bitsoff[SETWORD] =
     {
       0xFFFFFFFF,0xFFFFFFFE,0xFFFFFFFC,0xFFFFFFF8,0xFFFFFFF0,0xFFFFFFE0,0xFFFFFFC0,
       0xFFFFFF80,0xFFFFFF00,0xFFFFFE00,0xFFFFFC00,0xFFFFF800,0xFFFFF000,0xFFFFE000,
@@ -332,8 +332,10 @@ namespace OpenBabel
       {
         startpos = line.find_first_not_of(" \t\r\n",startpos);
         endpos   = line.find_first_of(" \t\r\n",startpos);
+        if (endpos == std::string::npos)
+          endpos = line.size();
 
-        if (endpos < line.size() && startpos <= line.size())
+        if (startpos <= line.size())
           tokens.push_back(line.substr(startpos,endpos-startpos));
         else
           break;
