@@ -414,6 +414,7 @@ namespace OpenBabel
     if( !result )
       {
         obErrorLog.ThrowError(__FUNCTION__, "Unable to allocate byte codes for biomolecule residue perception.", obError);
+        return (result);
       }
     result->type = type;
     result->eval.next     = NULL;
@@ -1251,10 +1252,14 @@ namespace OpenBabel
                   if (!nbr->IsHydrogen())
                     neighbour[count++] = nbr;
 
-                na = neighbour[0];
-                nb = neighbour[1];
-                nc = neighbour[2];
-                nd = neighbour[3];
+                if (count >= 1)
+                  na = neighbour[0];
+                if (count >= 2)
+                  nb = neighbour[1];
+                if (count >= 3)
+                  nc = neighbour[2];
+                if (count >= 4)
+                  nd = neighbour[3];
 
                 for ( i = 0 ; i < tmax ; i++ )
                   if ( templ[i].flag & bitmasks[idx] )
@@ -1373,9 +1378,12 @@ namespace OpenBabel
 
     resnos[idx] = r;
 
-    na = neighbour[0];
-    nb = neighbour[1];
-    nc = neighbour[2];
+    if (count >= 1)
+      na = neighbour[0];
+    if (count >= 2)
+      nb = neighbour[1];
+    if (count >= 3)
+      nc = neighbour[2];
 
     switch( atomids[i] )
       {
@@ -1644,7 +1652,6 @@ namespace OpenBabel
   void OBChainsParser::TraceNucleicChain(OBMol &mol, unsigned int i, int r)
   {
     unsigned int neighbour[4];
-    unsigned int na,nb,nc;
     int count;
     int j,k;
 
@@ -1663,10 +1670,6 @@ namespace OpenBabel
 
     resnos[i] = r;
 
-    na = neighbour[0];
-    nb = neighbour[1];
-    nc = neighbour[2];
-
     switch( atomids[i] )
       {
       case(AI_P):
