@@ -25,6 +25,7 @@ GNU General Public License for more details.
 #include <algorithm> // std::reverse
 #include <iterator> // std::istream_iterator
 #include <openbabel/stereo/stereo.h>
+#include <openbabel/stereo/cistrans.h>
 #include <openbabel/obiter.h>
 
 #include <cmath>
@@ -49,7 +50,7 @@ namespace OpenBabel
           bondSpacing(6.0), bondWidth(8.0), fontSize(16), subscriptSize(13),
           aliasMode(false), bondColor("black"), options(0){}
 
-      void DrawSimpleBond(OBAtom *beginAtom, OBAtom *endAtom, int order);
+      void DrawSimpleBond(OBAtom *beginAtom, OBAtom *endAtom, int order, bool crossed_bond=false);
       void DrawWedge(OBAtom *beginAtom, OBAtom *endAtom);
       void DrawHash(OBAtom *beginAtom, OBAtom *endAtom);
       void DrawWobblyBond(OBAtom *beginAtom, OBAtom *endAtom);
@@ -321,7 +322,11 @@ namespace OpenBabel
         max_y = std::max(max_y, atom->GetY());
       }
 
-      const double margin = 40.0;
+      double margin;
+      if (d->options & noMargin)
+        margin = 5.0;
+      else
+        margin = 40.0;
       // translate all atoms so the bottom-left atom is at margin,margin
       for (atom = d->mol->BeginAtom(i); atom; atom = d->mol->NextAtom(i))
         atom->SetVector(atom->GetX() - min_x + margin, atom->GetY() - min_y + margin, 0.0);
@@ -335,7 +340,27 @@ namespace OpenBabel
     }
 
     d->painter->NewCanvas(width, height);
-    
+
+    // Identify and remember the ring bonds according to the SSSR
+    // - note that OBBond->IsInRing() includes bonds not included in the SSSR as the SSSR excludes very large rings
+    std::vector<OBRing*> rings(mol->GetSSSR());
+    OBBitVec ringBonds;
+    for (std::vector<OBRing*>::iterator k = rings.begin(); k != rings.end(); ++k) {
+      OBRing *ring = *k;
+      std::vector<int> indexes = ring->_path;
+      for (unsigned int l = 0; l < indexes.size(); ++l) {
+        OBAtom *begin = d->mol->GetAtom(indexes[l]);
+        OBAtom *end;
+        if (l+1 < indexes.size())
+          end = d->mol->GetAtom(indexes[l+1]);
+        else
+          end = d->mol->GetAtom(indexes[0]);
+
+        OBBond *ringBond = d->mol->GetBond(begin, end);
+        ringBonds.SetBitOn(ringBond->GetId());
+      }
+    }
+
     // draw bonds
     for (OBBond *bond = d->mol->BeginBond(j); bond; bond = d->mol->NextBond(j)) {
       OBAtom *begin = bond->GetBeginAtom();
@@ -358,12 +383,19 @@ namespace OpenBabel
           d->DrawWobblyBond(begin, end);
         }
       }
-      else if (!bond->IsInRing())
-        d->DrawSimpleBond(begin, end, bond->GetBO());
+      else if (!ringBonds.BitIsSet(bond->GetId())) { // Ring bonds are handled below
+        bool crossed_dbl_bond = false;
+        OBStereoFacade sf(d->mol);
+        if (sf.HasCisTransStereo(bond->GetId())) {
+          OBCisTransStereo *ct = sf.GetCisTransStereo(bond->GetId());
+          if (!ct->GetConfig().specified)
+            crossed_dbl_bond = true;
+        }
+        d->DrawSimpleBond(begin, end, bond->GetBO(), crossed_dbl_bond);
+      }
     }
 
     // draw ring bonds
-    std::vector<OBRing*> rings(mol->GetSSSR());
     OBBitVec drawnBonds;
     for (std::vector<OBRing*>::iterator k = rings.begin(); k != rings.end(); ++k) {
       OBRing *ring = *k;
@@ -434,15 +466,24 @@ namespace OpenBabel
         if(charge) {
           if(abs(charge)!=1)
             ss << abs(charge);
-          ss << (charge>0 ? "+" : "-") ;
+          if(charge>0)
+            ss << '+';
+          else if (charge<-1) //use underscore for single negative charge and minus if multiple
+            ss << '-';
+          else
+          {
+            ss << '_';
+            yoffset -= 0.5 * metrics.height;
+          }
         }
-        if(spin) {
-          ss << (spin==2 ? "." : "..");
-          yoffset += 0.5 * metrics.height;
-        }
-        if(spin || charge<0)
-          d->painter->SetFontSize(2 * metrics.fontSize);
         d->painter->DrawText(x + 0.4*metrics.width, y+yoffset, ss.str());
+        if(spin) {
+          string radchars = (spin==2 ? "." : "..");
+          //yoffset += 0.5 * metrics.height;
+          d->painter->SetFontSize(2 * metrics.fontSize);
+          d->painter->DrawText(x + (0.4 + ss.str().size())*metrics.width,
+            y+yoffset, radchars);
+        }
         d->painter->SetFontSize(metrics.fontSize);//restore
       }
  
@@ -593,7 +634,7 @@ namespace OpenBabel
     }
   } 
   
-  void OBDepictPrivate::DrawSimpleBond(OBAtom *beginAtom, OBAtom *endAtom, int order)
+  void OBDepictPrivate::DrawSimpleBond(OBAtom *beginAtom, OBAtom *endAtom, int order, bool crossed_dbl_bond)
   {
     vector3 begin = beginAtom->GetVector();
     vector3 end = endAtom->GetVector();
@@ -618,7 +659,8 @@ namespace OpenBabel
         useAsymmetricDouble = false;
       if (HasLabel(endAtom) && beginAtom->GetValence() == 3)
         useAsymmetricDouble = false;
-
+      if (crossed_dbl_bond)
+        useAsymmetricDouble = false; // The bond looks very strange otherwise in the case of cis
 
       if (!useAsymmetricDouble) {
         // style1
@@ -626,10 +668,18 @@ namespace OpenBabel
         // -----------
         // -----------
         vector3 offset = orthogonalLine * 0.5 * bondSpacing;
-        painter->DrawLine(begin.x() + offset.x(), begin.y() + offset.y(),
-                          end.x() + offset.x(), end.y() + offset.y());
-        painter->DrawLine(begin.x() - offset.x(), begin.y() - offset.y(),
-                          end.x() - offset.x(), end.y() - offset.y());
+        if (!crossed_dbl_bond) {
+          painter->DrawLine(begin.x() + offset.x(), begin.y() + offset.y(),
+                            end.x() + offset.x(), end.y() + offset.y());
+          painter->DrawLine(begin.x() - offset.x(), begin.y() - offset.y(),
+                            end.x() - offset.x(), end.y() - offset.y());
+        }
+        else {
+          painter->DrawLine(begin.x() + offset.x(), begin.y() + offset.y(),
+                            end.x() - offset.x(), end.y() - offset.y());
+          painter->DrawLine(begin.x() - offset.x(), begin.y() - offset.y(),
+                            end.x() + offset.x(), end.y() + offset.y());
+        }
       } else {
         // style2
         //
@@ -711,7 +761,7 @@ namespace OpenBabel
     // compute the total width
     double totalWidth = 0.0;
     if ((alignment == Right) || (alignment == Left) || (label.find("H") == std::string::npos)) {
-      for (int i = 0; i < label.size(); ++i) {
+      for (unsigned int i = 0; i < label.size(); ++i) {
         if (!isalpha(label[i])) {
           painter->SetFontSize(subscriptSize);
           totalWidth += painter->GetFontMetrics(label.substr(i, 1)).width;
@@ -724,7 +774,7 @@ namespace OpenBabel
       painter->SetFontSize(fontSize);
       totalWidth = painter->GetFontMetrics(label.substr(0, label.find("H"))).width;
       double width = 0.0; 
-      for (int i = label.find("H"); i < label.size(); ++i) {
+      for (unsigned int i = label.find("H"); i < label.size(); ++i) {
         if (!isalpha(label[i])) {
           painter->SetFontSize(subscriptSize);
           width += painter->GetFontMetrics(label.substr(i, 1)).width;
@@ -769,7 +819,7 @@ namespace OpenBabel
     yOffsetSubscript = yOffset - metrics.descent;
     double xInitial = xOffset;
 
-    for (int i = 0; i < label.size(); ++i) {
+    for (unsigned int i = 0; i < label.size(); ++i) {
       if (label[i] == 'H') {
         if ((alignment == Up) || (alignment == Down))
           if (!str.empty()) {
@@ -821,7 +871,8 @@ namespace OpenBabel
     if (!subscript.empty()) {
       painter->SetFontSize(subscriptSize);
       OBFontMetrics metrics = painter->GetFontMetrics(subscript);
-      double yOffset = ispunct(subscript[subscript.size()-1]) || ispunct(subscript[0]) || ispunct(subscript[1])
+      double yOffset = ispunct(subscript[subscript.size()-1]) || ispunct(subscript[0]) 
+        || (subscript.size()>1 && ispunct(subscript[1]))
         ? -yOffsetSubscript : yOffsetSubscript;
       painter->DrawText(pos.x() + xOffset, pos.y() + yOffset, subscript);
     }
