@@ -2,48 +2,48 @@
 Copyright (C) 1998-2001 by OpenEye Scientific Software, Inc.
 Some portions Copyright (C) 2001-2006 by Geoffrey R. Hutchison
 Some portions Copyright (C) 2004 by Chris Morley
- 
+
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation version 2 of the License.
- 
+
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 ***********************************************************************/
 
-#include "mol.h"
-#include "obconversion.h"
+#include <openbabel/babelconfig.h>
+#include <openbabel/obmolecformat.h>
 
 using namespace std;
 namespace OpenBabel
 {
 
-class CSRFormat : public OBFormat
-{
-public:
+  class CSRFormat : public OBMoleculeFormat
+  {
+  public:
     //Register this format type ID
     CSRFormat()
     {
-        OBConversion::RegisterFormat("csr",this);
+      OBConversion::RegisterFormat("csr",this);
     }
 
     virtual const char* Description() //required
     {
-        return
-            "Accelrys/MSI Quanta CSR format\n \
-            No comments yet\n";
+      return
+        "Accelrys/MSI Quanta CSR format\n"
+        "No comments yet\n";
     };
 
-  virtual const char* SpecificationURL()
-  {return "";}; //optional
+    virtual const char* SpecificationURL()
+    {return "";}; //optional
 
     //Flags() can return be any the following combined by | or be omitted if none apply
     // NOTREADABLE  READONEONLY  NOTWRITABLE  WRITEONEONLY
     virtual unsigned int Flags()
     {
-        return NOTREADABLE;
+      return NOTREADABLE;
     };
 
     //*** This section identical for most OBMol conversions ***
@@ -51,28 +51,7 @@ public:
     /// The "API" interface functions
     virtual bool WriteMolecule(OBBase* pOb, OBConversion* pConv);
 
-    ////////////////////////////////////////////////////
-    /// The "Convert" interface functions
-
-    virtual bool WriteChemObject(OBConversion* pConv)
-    {
-        //Retrieve the target OBMol
-        OBBase* pOb = pConv->GetChemObject();
-        OBMol* pmol = dynamic_cast<OBMol*> (pOb);
-        bool ret=false;
-        if(pmol)
-            ret=WriteMolecule(pmol,pConv);
-
-	std::string auditMsg = "OpenBabel::Write molecule Accelrys/MSI Quanta CSR format";
-	obErrorLog.ThrowError(__FUNCTION__,
-			      auditMsg,
-			      obAuditMsg);
-
-        delete pOb;
-        return ret;
-    };
-
-private:
+  private:
     //	static bool FirstTime = true; Use new framework functions
     int MolCount; //was = 1;
 
@@ -82,19 +61,19 @@ private:
     void WriteCSRCoords(ostream&,OBMol&);
 
 
-};
-//***
+  };
+  //***
 
-//Make an instance of the format class
-CSRFormat theCSRFormat;
+  //Make an instance of the format class
+  CSRFormat theCSRFormat;
 
-////////////////////////////////////////////////////////////////
+  ////////////////////////////////////////////////////////////////
 
-bool CSRFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
-{
+  bool CSRFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
+  {
     OBMol* pmol = dynamic_cast<OBMol*>(pOb);
     if(pmol==NULL)
-        return false;
+      return false;
 
     //Define some references so we can use the old parameter names
     ostream &ofs = *pConv->GetOutStream();
@@ -102,20 +81,20 @@ bool CSRFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
 
     //  if (FirstTime)
     if(pConv->GetOutputIndex()==1)
-    {
+      {
         WriteCSRHeader(ofs,mol);
         //FirstTime = false;
         MolCount=1;
-    }
+      }
 
     WriteCSRCoords(ofs,mol);
     MolCount++;
 
     return(true);
-}
+  }
 
-void CSRFormat::WriteCSRHeader(ostream &ofs,OBMol &mol)
-{
+  void CSRFormat::WriteCSRHeader(ostream &ofs,OBMol &mol)
+  {
     char *molnames;
     int nmol, natom;
 
@@ -142,10 +121,10 @@ void CSRFormat::WriteCSRHeader(ostream &ofs,OBMol &mol)
     WriteSize(sizeof(int),ofs);
 
     delete [] molnames;
-}
+  }
 
-void CSRFormat::WriteCSRCoords(ostream &ofs,OBMol &mol)
-{
+  void CSRFormat::WriteCSRCoords(ostream &ofs,OBMol &mol)
+  {
     int the_size,jconf;
     double x,y,z,energy;
     char title[100];
@@ -168,48 +147,47 @@ void CSRFormat::WriteCSRCoords(ostream &ofs,OBMol &mol)
     WriteSize(mol.NumAtoms()*sizeof(double),ofs);
 
     OBAtom *atom;
-    vector<OBNodeBase*>::iterator i;
+    vector<OBAtom*>::iterator i;
     for (atom = mol.BeginAtom(i);atom;atom = mol.NextAtom(i))
-    {
+      {
         x = atom->x();
         ofs.write((char*)&x,sizeof(double));
-    }
+      }
     WriteSize(mol.NumAtoms()*sizeof(double),ofs);
 
     WriteSize(mol.NumAtoms()*sizeof(double),ofs);
     for (atom = mol.BeginAtom(i);atom;atom = mol.NextAtom(i))
-    {
+      {
         y = atom->y();
         ofs.write((char*)&y,sizeof(double));
-    }
+      }
     WriteSize(mol.NumAtoms()*sizeof(double),ofs);
 
     WriteSize(mol.NumAtoms()*sizeof(double),ofs);
     for (atom = mol.BeginAtom(i);atom;atom = mol.NextAtom(i))
-    {
+      {
         z = atom->z();
         ofs.write((char*)&z,sizeof(double));
-    }
+      }
     WriteSize(mol.NumAtoms()*sizeof(double),ofs);
 
     delete [] tag;
-}
+  }
 
-void CSRFormat::WriteSize(int size,ostream &ofs)
-{
+  void CSRFormat::WriteSize(int size,ostream &ofs)
+  {
     ofs.write((char*)&size,sizeof(int));
-}
+  }
 
-char* CSRFormat::PadString(char *input, int size)
-{
-    unsigned int i;
+  char* CSRFormat::PadString(char *input, int size)
+  {
     char *output;
 
-    output = new char [size];
+    output = new char[size];
     memset(output, ' ', size);
     strncpy(output, input, strlen(input));
     output[ size - 1] = '\0';
     return(output);
-}
+  }
 
 } //namespace OpenBabel
