@@ -2,11 +2,11 @@
 Copyright (C) 1998-2001 by OpenEye Scientific Software, Inc.
 Some portions Copyright (C) 2001-2006 by Geoffrey R. Hutchison
 Some portions Copyright (C) 2004 by Chris Morley
- 
+
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation version 2 of the License.
- 
+
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -31,8 +31,8 @@ namespace OpenBabel
     virtual const char* Description() //required
     {
       return
-        "ChemDraw Connection Table format \n \
-            No comments yet\n";
+        "ChemDraw Connection Table format\n"
+        "No comments yet\n";
     };
 
     virtual const char* SpecificationURL()
@@ -104,7 +104,7 @@ namespace OpenBabel
     OBMol* pmol = pOb->CastAndClear<OBMol>();
     if(pmol==NULL)
       return false;
-  
+
     //Define some references so we can use the old parameter names
     istream &ifs = *pConv->GetInStream();
     OBMol &mol = *pmol;
@@ -128,7 +128,7 @@ namespace OpenBabel
 
     ifs.getline(buffer,BUFF_SIZE);
     sscanf(buffer," %d %d", &natoms, &nbonds);
-  
+
     for (unsigned int i = 1; i <= natoms; i ++)
       {
         if (!ifs.getline(buffer,BUFF_SIZE)) return(false);
@@ -155,7 +155,7 @@ namespace OpenBabel
         }
 
     // clean out remaining blank lines
-    while(ifs.peek() != EOF && ifs.good() && 
+    while(ifs.peek() != EOF && ifs.good() &&
           (ifs.peek() == '\n' || ifs.peek() == '\r'))
       ifs.getline(buffer,BUFF_SIZE);
 
