@@ -233,6 +233,7 @@ int ChemKinFormat::ReadLine(istream& ifs )
     //discard lines that are empty or contain just a comment
     if(Trim(ln).empty() || ln[0]=='!')
       ln.clear();
+    comment.clear();
   }
   string::size_type eqpos, commentpos;
   commentpos = ln.find('!');
@@ -242,8 +243,6 @@ int ChemKinFormat::ReadLine(istream& ifs )
     comment = ln.substr(commentpos+1);
     ln.erase(commentpos);
   }
-  else
-    comment.clear();
 
   eqpos = ln.find('=');
   //eof may have been set, but we need ReadMolecule() to be called again to process this line
@@ -305,7 +304,7 @@ bool ChemKinFormat::ReadHeader(istream& ifs, OBConversion* pConv)
       double EFactor[6]   ={   1.0    ,   0.001  ,    4.1816    ,   0.041816   ,   1.98  , 0.0};
       double AvFactor = 6.023E23;
 
-      for(int i=1;i<toks.size();++i)
+      for (unsigned int i=1; i<toks.size(); ++i)
       {
         for(int j=0;j<6;++j)
           if(!strcasecmp(toks[i].c_str(), EKeywords[j].c_str()))
@@ -449,7 +448,7 @@ bool ChemKinFormat::ParseReactionLine(OBReaction* pReact, OBConversion* pConv)
           ln.clear();
           return false;
         }
-        for(int i=0;i<mult;++i)
+        for (unsigned int i=0; i<mult; ++i)
           pReact->AddReactant(sp);
         continue;
       }
@@ -569,7 +568,7 @@ bool ChemKinFormat::ParseReactionLine(OBReaction* pReact, OBConversion* pConv)
             ln.clear();
             return false;
           }
-          for(int j=0;j<mult;++j)
+          for (unsigned int j=0; j<mult; ++j)
             pReact->AddProduct(sp);
         }
         else
@@ -834,11 +833,11 @@ bool ChemKinFormat::WriteHeader(OBConversion* pConv)
 
   ofs << "SPECIES\n";
   vector<string>::iterator sitr;
-  int maxlen=0;
+  unsigned int maxlen=0;
   for(sitr= species.begin();sitr!=species.end();++sitr)
     if(sitr->size()>maxlen) maxlen = sitr->size();
 
-  int n=0;
+  unsigned int n=0;
   for(sitr=species.begin();sitr!=species.end();++sitr, ++n)
   {
     if(maxlen>0 && n > 80 / maxlen)
