@@ -265,7 +265,9 @@ namespace OpenBabel
     //private:
     /// Separate the file in data blocks and parse them to sort tags, loops and comments.
     /// All is stored in the original strings.
-    void Parse(std::stringstream &in);
+    ///
+    /// Returns the name of the next data block
+    void Parse(std::istream &in);
     /// The data blocks, after parsing. The key is the name of the data block
     std::map<std::string,CIFData> mvData;
     /// Global comments, outside and data block
@@ -311,7 +313,7 @@ namespace OpenBabel
             if(loop->second.find("_atom_site_Cartn_y")!=loop->second.end()) empty_iucrjournal_block=false;
             if(loop->second.find("_atom_site_Cartn_z")!=loop->second.end()) empty_iucrjournal_block=false;
           }
-        if(empty_iucrjournal_block) 
+        if(empty_iucrjournal_block)
           {
             stringstream ss;
             ss << "CIF WARNING: found en empty 'data_global' block - SKIPPING\n"
@@ -369,7 +371,7 @@ namespace OpenBabel
         mvLatticePar[3] = static_cast<float> (mvLatticePar[3] * DEG_TO_RAD);// pi/180
         mvLatticePar[4] = static_cast<float> (mvLatticePar[4] * DEG_TO_RAD);
         mvLatticePar[5] = static_cast<float> (mvLatticePar[5] * DEG_TO_RAD);
-        
+
         // Fill values depending on spacegroup, *only* when missing
         if((spgid>2)&&(spgid<=15))
         {// :TODO: monoclinic spg, depending on unique axis....
@@ -397,7 +399,7 @@ namespace OpenBabel
             if(mvLatticePar[0]==0) mvLatticePar[0]=a;
             if(mvLatticePar[1]==0) mvLatticePar[1]=a;
             if(mvLatticePar[2]==0) mvLatticePar[2]=a;
-            
+
             float alpha=0;
             if(mvLatticePar[3]>alpha) alpha=mvLatticePar[3];
             if(mvLatticePar[4]>alpha) alpha=mvLatticePar[4];
@@ -542,6 +544,25 @@ namespace OpenBabel
             if(verbose) cout<<"Found spacegroup Hermann-Mauguin symbol (with OBSOLETE CIF #1.0 TAG):"<<mSpacegroupHermannMauguin<<endl;
           }
       }
+    // DDL2 tag is "_space_group.IT_coordinate_system_code", converted by the cif reader to "_space_group_IT_coordinate_system_code"
+    positem=mvItem.find("_space_group_IT_coordinate_system_code");
+    if(positem!=mvItem.end())
+      {
+        if(verbose) cout<<"Found spacegroup IT_coordinate_system_code:"<<positem->second<<endl;
+        if((mSpacegroupHermannMauguin.length()>0) && (positem->second=="1" || positem->second=="2"))
+        {
+          // this is a HACK which will work as long as the HM symbols in spacegroups.txt have the ":1" or ":2" extension listed, when needed
+          mSpacegroupHermannMauguin=mSpacegroupHermannMauguin+string(":")+positem->second;
+        }
+        else
+        {
+          stringstream ss;
+          ss << "CIF Error: found DDL2 tag _space_group.IT_coordinate_system_code ("<<positem->second<<")"<<endl
+             <<"            but could not interpret it ! Origin choice or axis may be incorrect.";
+          obErrorLog.ThrowError(__FUNCTION__, ss.str(), obWarning);
+        }
+      }
+
     mSpaceGroup=NULL;
     // be forgiving - if spg not found, try again
     // Prefer Hall > HM == number, as Hall symbol is truly unique
@@ -562,7 +583,9 @@ namespace OpenBabel
     }
     if(mSpaceGroup == NULL) {
       SpaceGroup *sg = new SpaceGroup();
-      positem=mvItem.find("_symmetry_equiv_pos_as_xyz");
+      positem=mvItem.find("_space_group_symop_operation_xyz");
+      if(positem==mvItem.end())
+        positem=mvItem.find("_symmetry_equiv_pos_as_xyz");
       if(positem!=mvItem.end())
         {
           sg->AddTransform (positem->second);
@@ -574,7 +597,9 @@ namespace OpenBabel
           {
             map<ci_string,vector<string> >::const_iterator pos;
             unsigned i, nb;
-            pos=loop->second.find("_symmetry_equiv_pos_as_xyz");
+            pos=loop->second.find("_space_group_symop_operation_xyz");
+            if (pos==loop->second.end())
+              pos=loop->second.find("_symmetry_equiv_pos_as_xyz");
             if (pos!=loop->second.end())
               {
                 nb=pos->second.size();
@@ -586,7 +611,10 @@ namespace OpenBabel
           }
         if (found)
           mSpaceGroup = SpaceGroup::Find(sg);
-        delete sg;
+        if (mSpaceGroup == NULL && sg->IsValid())
+          mSpaceGroup = sg;
+        else
+          delete sg;
       }
     }
     if(mSpaceGroup == NULL)
@@ -929,21 +957,26 @@ namespace OpenBabel
 
   CIF::CIF(istream &is, const bool interpret,const bool verbose)
   {
-    //Copy to an iostream so that we can put back characters if necessary
-    stringstream in;
-    char c;
-    while(is.get(c))in.put(c);
-    this->Parse(in);
-    // Extract structure from blocks
-    if(interpret)
-      for(map<string,CIFData>::iterator posd=mvData.begin();posd!=mvData.end();++posd)
-        posd->second.ExtractAll(verbose);
+    bool found_atoms=false;
+    while(!found_atoms)
+    {
+      // :TODO: we don't need a vector of CIFData, since only one block is read at a time
+      mvData.clear();
+      this->Parse(is);
+      // Extract structure from 1 block
+      if(interpret)
+        for(map<string,CIFData>::iterator posd=mvData.begin();posd!=mvData.end();++posd)
+        {
+          posd->second.ExtractAll(verbose);
+          if(posd->second.mvAtom.size()>0) found_atoms=true;
+        }
+    }
   }
 
   bool iseol(const char c) { return ((c=='\n')||(c=='\r'));}
 
   /// Read one value, whether it is numeric, string or text
-  string CIFReadValue(stringstream &in,char &lastc)
+  string CIFReadValue(istream &in,char &lastc)
   {
     bool vv=false;//very verbose ?
     string value("");
@@ -1009,7 +1042,7 @@ namespace OpenBabel
     return value;
   }
 
-  void CIF::Parse(stringstream &in)
+  void CIF::Parse(istream &in)
   {
     bool vv=false;//very verbose ?
     char lastc=' ';
@@ -1041,10 +1074,14 @@ namespace OpenBabel
           }
         if((in.peek()=='d') || (in.peek()=='D'))
           {// Data
+            if(mvData.size()>0) return; // We want just a single data block
+
             string tmp;
             in>>tmp;
             block=tmp.substr(5);
             if(vv) cout<<endl<<endl<<"NEW BLOCK DATA: !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ->"<<block<<endl<<endl<<endl;
+
+
             mvData[block]=CIFData();
             mvData[block].mDataBlockName=tmp;
             continue;
@@ -1081,45 +1118,45 @@ namespace OpenBabel
             map<ci_string,vector<string> > lp;
             while(true)
               {
+                std::ios::pos_type pos0=in.tellg();
                 while(!isgraph(in.peek()) && !in.eof()) in.get(lastc);
                 if(in.eof()) break;
-                if(vv) cout<<"LOOP VALUES...: "<<(char)in.peek()<<" "<<endl;
                 if(in.peek()=='_') break;
                 if(in.peek()=='#')
                   {// Comment (in a loop ??)
-                    const std::ios::pos_type pos=in.tellg();
+                    //const std::ios::pos_type pos=in.tellg();
                     string tmp;
                     getline(in,tmp);
+                    pos0=in.tellg();
                     if(block=="") mvComment.push_back(tmp);
                     else mvData[block].mvComment.push_back(tmp);
                     lastc='\r';
                     if(vv) cout<<"Comment in a loop (?):"<<tmp<<endl;
-                    in.seekg(pos);
+                    //in.seekg(pos);
                     break;
                   }
-                const std::ios::pos_type pos=in.tellg();
-                in>>tmp;
-                if(vv) cout<<"WHATNEXT? "<<tmp;
+                //in>>tmp;
+                tmp=CIFReadValue(in,lastc);
                 if(ci_string(tmp.c_str())=="loop_")
                   {//go back and continue
-                    if(vv) cout<<endl<<"END OF LOOP :"<<tmp<<endl;
-                    in.seekg(pos);
+                    in.clear();
+                    in.seekg(pos0,std::ios::beg);
+                    if(vv) cout<<endl<<"END OF LOOP :"<<tmp<<","<<(char)in.peek()<<","<<in.tellg()<<endl;
                     break;
                   }
                 if(tmp.size()>=5)
                   if(ci_string(tmp.substr(0,5).c_str())=="data_")
                     {//go back and continue
-                      if(vv) cout<<endl<<"END OF LOOP :"<<tmp<<endl;
-                      in.seekg(pos);
+                      in.clear();
+                      in.seekg(pos0,std::ios::beg);
+                      if(vv) cout<<endl<<"END OF LOOP :"<<tmp<<","<<(char)in.peek()<<","<<in.tellg()<<endl;
                       break;
                     }
-                // go back
-                in.seekg(pos);
                 for(unsigned int i=0;i<tit.size();++i)
                   {//Read all values
-                    const string value=CIFReadValue(in,lastc);
-                    lp[tit[i]].push_back(value);
-                    if(vv) cout<<"     #"<<i<<" :  "<<value<<endl;
+                    if(i>0) tmp=CIFReadValue(in,lastc);
+                    lp[tit[i]].push_back(tmp);
+                    if(vv) cout<<" LOOP VALUE    #"<<lp[tit[i]].size()<<","<<i<<" :  "<<tmp<<endl;
                   }
               }
             // The key to the mvLoop map is the set of column titles
@@ -1340,9 +1377,23 @@ namespace OpenBabel
               else tmpSymbol="C";//Something went wrong, no symbol ! Default to C ??
 
               int atomicNum = etab.GetAtomicNum(tmpSymbol.c_str());
+              // Test for some oxygens with subscripts
+              if (atomicNum == 0 && tmpSymbol[0] == 'O') {
+                atomicNum = 8; // e.g. Ob, OH, etc.
+              }
+
               atom->SetAtomicNum(atomicNum); //set atomic number, or '0' if the atom type is not recognized
               atom->SetType(tmpSymbol); //set atomic number, or '0' if the atom type is not recognized
               atom->SetVector(posat->mCoordCart[0],posat->mCoordCart[1],posat->mCoordCart[2]);
+              if(posat->mLabel.size()>0)
+                {
+                  OBPairData *label = new OBPairData;
+                  label->SetAttribute("_atom_site_label");
+                  label->SetValue(posat->mLabel);
+                  label->SetOrigin(fileformatInput);
+                  atom->SetData(label);
+                }
+
             }
           if (!pConv->IsOption("b",OBConversion::INOPTIONS))
             pmol->ConnectTheDots();
@@ -1413,7 +1464,12 @@ namespace OpenBabel
         const SpaceGroup* pSG = pUC->GetSpaceGroup();
         if (pSG != NULL)
           {
-            ofs << "_space_group_name_H-M_alt '" << pSG->GetHMName() << "'" << endl;
+            // Do we have an extended HM symbol, with origin choice as ":1" or ":2" ? If so, remove it.
+            size_t n=pSG->GetHMName().find(":");
+            if(n==string::npos)
+              ofs << "_space_group_name_H-M_alt '" << pSG->GetHMName() << "'" << endl;
+            else
+              ofs << "_space_group_name_H-M_alt '" << pSG->GetHMName().substr(0,n) << "'" << endl;
             ofs << "_space_group_name_Hall '" << pSG->GetHallName() << "'" << endl;
             ofs << "loop_" <<endl
                 << "    _symmetry_equiv_pos_as_xyz" << endl;
@@ -1437,13 +1493,26 @@ namespace OpenBabel
     unsigned int i=0;
     FOR_ATOMS_OF_MOL(atom, *pmol)
       {
-        snprintf(buffer, BUFF_SIZE, "    %3s  %3s%d  %10.5f %10.5f %10.5f\n",
-                 etab.GetSymbol(atom->GetAtomicNum()),
-                 etab.GetSymbol(atom->GetAtomicNum()),
-                 ++i,
-                 atom->GetX(),
-                 atom->GetY(),
-                 atom->GetZ());
+        if (atom->HasData("_atom_site_label"))
+          {
+            OBPairData *label = dynamic_cast<OBPairData *> (atom->GetData("_atom_site_label"));
+            snprintf(buffer, BUFF_SIZE, "    %3s  %3s  %10.5f %10.5f %10.5f\n",
+                     etab.GetSymbol(atom->GetAtomicNum()),
+                     label->GetValue().c_str(),
+                     atom->GetX(),
+                     atom->GetY(),
+                     atom->GetZ());
+          }
+        else
+          {
+            snprintf(buffer, BUFF_SIZE, "    %3s  %3s%d  %10.5f %10.5f %10.5f\n",
+                     etab.GetSymbol(atom->GetAtomicNum()),
+                     etab.GetSymbol(atom->GetAtomicNum()),
+                     ++i,
+                     atom->GetX(),
+                     atom->GetY(),
+                     atom->GetZ());
+          }
         ofs << buffer;
       }
     return true;
