@@ -74,6 +74,8 @@ virtual const char* Description() //required
   "      #     Tanimoto >0.7 && Tanimoto < 0.9\n\n"
   "The datafile plus the ``-ifs`` option can be used instead of the index file.\n\n"
   "NOTE that the datafile MUST NOT be larger than 4GB. (A 32 pointer is used.)\n\n"
+  "Dative bonds like -[N+][O-](=O) are indexed as -N(=O)(=O), and when searching\n"
+  "the target molecule should be in the second form.\n\n"
 
   ".. seealso::\n\n"
 
@@ -207,7 +209,7 @@ virtual const char* Description() //required
           {
             //Finds molecules with Tanimoto > MinTani
             double MaxTani = 1.1;
-            int pos = txt.find( ',' );
+            size_t pos = txt.find(',');
             if( pos != string::npos ) {
               MaxTani = atof( txt.substr( pos + 1 ).c_str() );
             }
@@ -281,10 +283,8 @@ virtual const char* Description() //required
         end = unique(begin, end); //removed duplicates are after new end
       }
 
-      //Output the candidate molecules, filtering through s filter, unless the
-      //fingerprint type does not require it, or it was not requested
-      if(fs.GetFingerprint()->Flags() & OBFingerprint::FPT_UNIQUEBITS
-                    || pConv->IsOption("n",OBConversion::INOPTIONS) )
+      //Output the candidate molecules, filtering through s filter, unless it was not requested
+      if(pConv->IsOption("n", OBConversion::INOPTIONS) )
         pConv->RemoveOption("s",OBConversion::GENOPTIONS);
 
       pConv->SetLast(false);
