@@ -83,16 +83,22 @@ bool InChIFormat::ReadMolecule(OBBase* pOb, OBConversion* pConv)
 
   //Call the conversion routine in InChI code
   int ret = GetStructFromINCHI( &inp, &out );
+  delete[] nonconstinchi;
+  delete[] opts;
 
   if (ret!=inchi_Ret_OKAY)
   {
-    string mes = out.szMessage ? out.szMessage : "Conversion failed";
-    obErrorLog.ThrowError("InChI code", mes + '\n' + inchi, obWarning);
+    string mes = out.szMessage;
+    if (!mes.empty()) {
+      Trim(mes);
+      obErrorLog.ThrowError("InChI code", "For " + inchi + "\n  " + mes, obWarning);
+    }
+    if (ret!=inchi_Ret_WARNING)
+    {
+      obErrorLog.ThrowError("InChI code", "Reading InChI failed", obError);
+      return false;
+    }
   }
-  delete[] nonconstinchi;
-  delete[] opts;
-  if(ret)
-    return false;
 
   //Read name if requested e.g InChI=1/CH4/h1H4 methane
   //OR InChI=1/CH4/h1H4 "First alkane"  Quote can be any punct char and
@@ -142,23 +148,26 @@ bool InChIFormat::ReadMolecule(OBBase* pOb, OBConversion* pConv)
       pmol->AddBond(i+1, piat->neighbor[j]+1, piat->bond_type[j]);
     }
 
-    //OB takes care of implicit hydrogens, so num_iso_H[0] and num_iso_H[1] are ignored,
-    //except for H2, which has one explicit H and one implict H. OB doesn't add implicit H to H.
-    //Implicit D and T also need to be added explicitly.
-    for(int m=0;m<3;++m)
+    //Now use the implicit H info provided by InChI code to make explicit H in OBMol,
+    //assign spinMultiplicity, then remove the hydrogens to be consistent with old way.
+    //Add implicit hydrogen. m=0 is non-istopic H m=1,2,3 are isotope specified
+    for(int m=0;m<=3;++m)
     {
-      if(piat->num_iso_H[m] && (m>1 || *piat->elname=='H'))
+      if(piat->num_iso_H[m])// && (m>1 || *piat->elname=='H'))
       {
         for(int k=0;k<piat->num_iso_H[m];++k)
         {
           OBAtom* DorT = pmol->NewAtom();
           DorT->SetAtomicNum(1);
-          DorT->SetIsotope(m);
+          if(m>0)
+            DorT->SetIsotope(m);
           pmol->AddBond(i+1, pmol->NumAtoms(), 1);
         }
       }
     }
   }
+  pmol->AssignSpinMultiplicity(true); //true means no implicit H
+  pmol->DeleteHydrogens();
 
   //***@todo implicit H isotopes
   //Stereochemistry
@@ -266,6 +275,7 @@ bool InChIFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
 
   string ostring; //the inchi string
   inchi_Output inout;
+  inout.szInChI = NULL; // We are going to test this value later
 
   stringstream molID;
   if(strlen(mol.GetTitle())==0)
@@ -498,7 +508,7 @@ bool InChIFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
             if(pos!=string::npos)
             {
               mes.erase(pos,targ[i].size());
-              if(mes[pos]==';')
+              if(pos<mes.size() && mes[pos]==';')
                 mes[pos]=' ';
             }
           }
@@ -529,7 +539,7 @@ bool InChIFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
   if(pConv->IsOption("K")) //Generate InChIKey and add after InChI on same line
   {
     char szINCHIKey[28];
-    GetStdINCHIKeyFromStdINCHI(ostring.c_str(), szINCHIKey);
+    GetINCHIKeyFromINCHI(ostring.c_str(), 0 ,0, szINCHIKey, NULL, NULL);
     ostring = szINCHIKey;
   }
 
@@ -566,25 +576,29 @@ bool InChIFormat::WriteMolecule(OBBase* pOb, OBConversion* pConv)
 
   ofs << ostring << endl;
 
-  if (pConv->IsOption("a"))
-    ofs << inout.szAuxInfo << endl;
+  // Note that inout.szInChI will still be NULL if this is an InChI->InChIKey conversion
+  // and so the following section will not apply.
+  if (inout.szInChI != NULL) {
+    if (pConv->IsOption("a"))
+      ofs << inout.szAuxInfo << endl;
 
-  if(pConv->IsOption("l"))
-    //Display InChI log message. With multiple molecules, it appears only once
-    obErrorLog.ThrowError("InChI log", inout.szLog, obError, onceOnly);
+    if(pConv->IsOption("l"))
+      //Display InChI log message. With multiple molecules, it appears only once
+      obErrorLog.ThrowError("InChI log", inout.szLog, obError, onceOnly);
 
-  if(pConv->IsOption("e"))
-  {
-    if(pConv->GetOutputIndex()==1)
-      firstInchi = inout.szInChI;
-    else
+    if(pConv->IsOption("e"))
     {
-      ofs << "Molecules " << firstID << "and " << molID.str();
-      ofs << InChIErrorMessage(CompareInchi(firstInchi.c_str(), inout.szInChI)) << endl;
+      if(pConv->GetOutputIndex()==1)
+        firstInchi = inout.szInChI;
+      else
+      {
+        ofs << "Molecules " << firstID << "and " << molID.str();
+        ofs << InChIErrorMessage(CompareInchi(firstInchi.c_str(), inout.szInChI)) << endl;
+      }
     }
+    FreeStdINCHI(&inout);
   }
 
-  FreeStdINCHI(&inout);
   return true;
 }
 
@@ -732,7 +746,7 @@ char* InChIFormat::GetInChIOptions(OBConversion* pConv, bool Reading)
 #endif
 
   string sopts;
-  for(int i=0;i<optsvec.size();++i)
+  for (unsigned int i = 0; i < optsvec.size(); ++i)
     sopts += ch + optsvec[i];
   opts = new char[strlen(sopts.c_str())+1]; //has to be char, not const char
   return strcpy(opts, sopts.c_str());
