@@ -49,11 +49,28 @@ namespace OpenBabel
       {
         return "MDL MOL format\n"
                "Reads and writes V2000 and V3000 versions\n\n"
+               
+               "Open Babel supports an extension to the MOL file standard\n"
+               "that allows cis/trans and tetrahedral stereochemistry to be\n"
+               "stored in 0D MOL files. The tetrahedral stereochemistry is\n"
+               "stored as the atom parity, while the cis/trans stereochemistry\n"
+               "is stored using Up and Down bonds similar to how it is\n"
+               "represented in a SMILES string. Use the ``S`` option\n"
+               "when reading or writing if you want to avoid storing\n"
+               "or interpreting stereochemistry in 0D MOL files.\n\n"
+
                "Read Options, e.g. -as\n"
                " s  determine chirality from atom parity flags\n"
-               "       The default setting is to ignore atom parity and\n"
+               "       The default setting for 2D and 3D is to ignore atom parity and\n"
                "       work out the chirality based on the bond\n"
-               "       stereochemistry.\n"
+               "       stereochemistry (2D) or coordinates (3D).\n"
+               "       For 0D the default is already to determine the chirality\n"
+               "       from the atom parity.\n"
+               " S  do not read stereochemistry from 0D MOL files\n"
+               "       Open Babel supports reading and writing cis/trans\n"
+               "       and tetrahedral stereochemistry to 0D MOL files.\n"
+               "       This is an extension to the standard which you can\n"
+               "       turn off using this option.\n"
                " T  read title only\n"
                " P  read title and properties only\n"
                "       When filtering an sdf file on title or properties\n"
@@ -64,7 +81,8 @@ namespace OpenBabel
                "Write Options, e.g. -x3\n"
                " 3  output V3000 not V2000 (used for >999 atoms/bonds) \n"
                " m  write no properties\n"
-               " w  use wedge and hash bonds from input (2D structures only)\n"
+               " w  use wedge and hash bonds from input (2D only)\n"
+               " S  do not store cis/trans stereochemistry in 0D MOL files\n"
                " A  output in Alias form, e.g. Ph, if present\n\n";
       }
 
@@ -107,7 +125,7 @@ namespace OpenBabel
       bool ReadRGroupBlock(istream& ifs,OBMol& mol, OBConversion* pConv);
       bool ReadUnimplementedBlock(istream& ifs,OBMol& mol, OBConversion* pConv, string& blockname);
       bool WriteV3000(ostream& ofs,OBMol& mol, OBConversion* pConv);
-      void ReadPropertyLines(istream& ifs, OBMol& mol);
+      bool ReadPropertyLines(istream& ifs, OBMol& mol);
       bool TestForAlias(const string& symbol, OBAtom* at, vector<pair<AliasData*,OBAtom*> >& aliases);
 
     private:
@@ -116,8 +134,10 @@ namespace OpenBabel
       };
       bool  HasProperties;
       string GetTimeDate();
+      void GetUpDown(OBMol& mol, map<OBBond*, OBStereo::BondDirection> &updown, set<OBBond*> &stereodbl);
       void GetParity(OBMol& mol, map<OBAtom*, Parity> &parity);
       void TetStereoFromParity(OBMol& mol, vector<MDLFormat::Parity> &parity, bool deleteExisting=false);
+      void CisTransFromUpDown(OBMol *mol, std::map<OBBond*, OBStereo::BondDirection> *updown);
       int ReadIntField(const char *s);
       unsigned int ReadUIntField(const char *s);
      // Helper for 2.3 -- is this atom a metal
@@ -302,11 +322,31 @@ namespace OpenBabel
 
     natoms = ReadUIntField((line.substr(0, 3)).c_str());
     nbonds = ReadUIntField((line.substr(3, 3)).c_str());
+    
+    // Store the Chiral Flag
+    unsigned int chiralFlagVal = ReadUIntField((line.substr(12, 3)).c_str());
+    if (chiralFlagVal > 1)
+    {
+      errorMsg << "WARNING: The Chiral Flag should be either 0 or 1. The value of "
+               << chiralFlagVal << " will be ignored.\n";	        
+	    obErrorLog.ThrowError(__FUNCTION__, errorMsg.str() , obWarning);
+    }
+    else
+    {
+      OBPairData *chiralFlag = new OBPairData();
+      chiralFlag->SetAttribute("MOL Chiral Flag");
+      chiralFlag->SetOrigin(local);
+      std::stringstream convert;
+      convert << chiralFlagVal;
+      chiralFlag->SetValue(convert.str()); // 1 ("Absolute Chirality"), 0 ("Relative Chirality")
+      mol.SetData(chiralFlag);
+    }
 
     if(ReadUIntField((line.substr(6, 3)).c_str())>0)
       obErrorLog.ThrowError(__FUNCTION__,
-        "Either the file contains Atom Lists, which are not currently supported and are ignored\n"
-        "or the atom or bond count is >999, which is not allowed in V2000 MDL files.",
+        "WARNING: Problems reading the Count line of an MDL file\n"
+        "There may be erroneous addition spaces or\n"
+        "the file may contains Atom Lists, which are ignored\n",
         obWarning);
 
     mol.BeginModify();
@@ -399,12 +439,21 @@ namespace OpenBabel
           }
         }
         parities.push_back(parity);
+        
         // valence
+        bool forceNoH = false;
         if (line.size() >= 50) {
           int valence = ReadIntField(line.substr(48, 3).c_str());
           if(valence!=0) // Now no H with any value
-            patom->ForceNoH();
+            forceNoH = true;
         }
+        if (forceNoH)
+          patom->ForceNoH(); // There are no additional implicit Hs
+        else
+          patom->ForceImplH(); // There could be additional implicit Hs
+                               // - if we don't set this, then the presence of a single explicit H
+                               //   will cause AssignSpinMultiplicity to assume no additional implicit Hs
+
 
 //        if (!mol.AddAtom(atom))
 //          return false;
@@ -440,7 +489,8 @@ namespace OpenBabel
 	}
         if (begin == 0 || end == 0 || order == 0 || begin > mol.NumAtoms() || end > mol.NumAtoms()) {
 	        errorMsg << "WARNING: Problems reading a MDL file\n";
-	        errorMsg << "Invalid bond specification, atom numbers or bond order are wrong.\n";
+	        errorMsg << "Invalid bond specification, atom numbers or bond order are wrong;\n";
+	        errorMsg << "each should be in a field of three characters.\n";
 	        obErrorLog.ThrowError(__FUNCTION__, errorMsg.str() , obWarning);
           return false;
 	      }
@@ -479,29 +529,6 @@ namespace OpenBabel
 	        obErrorLog.ThrowError(__FUNCTION__, errorMsg.str() , obWarning);
 	        return false;
 	      }
-        if (stereo) {
-          OBStereo::BondDirection bd;
-          switch (stereo) {
-            case 1:
-              bd = OBStereo::UpBond;
-              break;
-            case 6:
-              bd = OBStereo::DownBond;
-              break;
-            case 4:
-              bd = OBStereo::UnknownDir;
-              break;
-            case 3: // Unspecified stereo around double bond
-              if (order==2)
-                bd = OBStereo::UnknownDir;
-              break;
-            default:
-              bd = OBStereo::NotStereo;
-              break;
-          }
-          if (bd != OBStereo::NotStereo)
-            updown[mol.GetBond(begin, end)] = bd;
-        }
       }
 
       //
@@ -532,7 +559,7 @@ namespace OpenBabel
             OBAtom* at = mol.GetAtom(atomnum);
             if (at) {
               at->SetData(ad);
-              at->SetAtomicNum(0);
+              //at->SetAtomicNum(0); Now leave element as found
               //The alias has now been added as a dummy atom with a AliasData object.
               //Delay the chemical interpretation until the rest of the molecule has been built
               aliases.push_back(make_pair(ad, at));
@@ -544,7 +571,7 @@ namespace OpenBabel
         if ((line.substr(0, 6) != "M  CHG") && (line.substr(0, 6) != "M  RAD") &&
             (line.substr(0, 6) != "M  ISO"))
           continue;
-        int n = -1;
+        unsigned int n = 0;
         if (line.size() >= 9)
           n = ReadUIntField((line.substr(6, 3)).c_str()); //entries on this line
         if (n <= 0 || n > 99 || 6+n*8 > line.size()) { //catch ill-formed line
@@ -612,6 +639,22 @@ namespace OpenBabel
       ad->Expand(mol, atomnum); //Make chemically meaningful, if possible.
     }
 
+    // Set up the updown map we are going to use to derive stereo info
+    FOR_BONDS_OF_MOL(bond, mol) {
+      OBStereo::BondDirection bd = OBStereo::NotStereo;;
+      unsigned int flag = bond->GetFlags();
+      if (flag & OBBond::Wedge)
+        bd = OBStereo::UpBond;
+      if (flag & OBBond::Hash)
+        bd = OBStereo::DownBond;
+      if (flag & OBBond::WedgeOrHash)
+        bd = OBStereo::UnknownDir;
+      if (flag & OBBond::CisOrTrans && bond->GetBondOrder()==2)
+        bd = OBStereo::UnknownDir;
+      if (bd != OBStereo::NotStereo)
+        updown[&*bond] = bd;
+    }
+
     mol.AssignSpinMultiplicity();
     mol.EndModify();
 
@@ -623,7 +666,11 @@ namespace OpenBabel
     }
 
     //Get property lines
-    ReadPropertyLines(ifs, mol);
+    if(!ReadPropertyLines(ifs, mol)) {
+      //Has read the first line of the next reaction in RXN format
+      pConv->AddOption("$RXNread");
+      return true;
+    }
 
     if (mol.Has3D()) {
       if (!setDimension)
@@ -633,6 +680,22 @@ namespace OpenBabel
       if (pConv->IsOption("s", OBConversion::INOPTIONS)) { // Use the parities for tet stereo instead
         TetStereoFromParity(mol, parities, true); // True means "delete existing TetStereo first"
       }
+
+      // For unspecified cis/trans stereos, set their Configs to unspecified
+      // This should really be done in CisTransFrom3D like in CisTransFrom2D but can't change the API now :-/
+      map<OBBond*, OBStereo::BondDirection>::const_iterator bd_it;
+      OpenBabel::OBStereoFacade facade(&mol);
+      for(bd_it=updown.begin(); bd_it!=updown.end(); ++bd_it) {
+        OBBond* bond = bd_it->first;
+        if (bond->GetBondOrder()!=2 || bd_it->second != OBStereo::UnknownDir)
+          continue; // Only continue for those double bonds with UnknownDir
+        OBCisTransStereo* ct = facade.GetCisTransStereo(bond->GetId());
+        if (ct) {
+          OBCisTransStereo::Config config = ct->GetConfig();
+          config.specified = false;
+          ct->SetConfig(config);
+        }
+      }
     } else
     if (mol.Has2D()) {
       if (!setDimension)
@@ -645,28 +708,13 @@ namespace OpenBabel
     } else { // 0D
       if (!setDimension)
         mol.SetDimension(0);
-      // The 0D format is not considered to store stereochemistry, but
-      // if you specify the "s" option, then atom parities from the
-      // MOL file will be used to create tetrahedral stereochemistry
-      if (pConv->IsOption("s", OBConversion::INOPTIONS))
+      // Atom parities from the MOL file will be used to create tetrahedral stereochemistry
+      // unless you specified the S option (but not s).
+      if (pConv->IsOption("s", OBConversion::INOPTIONS) || pConv->IsOption("S", OBConversion::INOPTIONS)==NULL)
         TetStereoFromParity(mol, parities);
       StereoFrom0D(&mol);
-    }
-
-    // For unspecified cis/trans stereos, set their Configs to unspecified
-    map<OBBond*, OBStereo::BondDirection>::const_iterator bd_it;
-    OpenBabel::OBStereoFacade facade(&mol);
-    for(bd_it=updown.begin(); bd_it!=updown.end(); ++bd_it) {
-      OBBond* bond = bd_it->first;
-      if (bond->GetBondOrder()!=2 || bd_it->second != OBStereo::UnknownDir)
-        continue; // Only continue for those double bonds with UnknownDir
-
-      OBCisTransStereo* ct = facade.GetCisTransStereo(bond->GetId());
-      if (ct) {
-        OBCisTransStereo::Config config = ct->GetConfig();
-        config.specified = false;
-        ct->SetConfig(config);
-      }
+      if (pConv->IsOption("S", OBConversion::INOPTIONS)==NULL)
+        CisTransFromUpDown(&mol, &updown);
     }
 
     return true;
@@ -683,8 +731,14 @@ namespace OpenBabel
 
     // Recommend using --gen2D or --gen3D
     if (mol.GetDimension()==0)
-      obErrorLog.ThrowError(__FUNCTION__, "No 2D or 3D coordinates exist. Any stereochemical information will"
-      " be lost. To generate 2D or 3D coordinates use --gen2D or --gen3d.", obWarning, onceOnly);
+    {
+      if (pConv->IsOption("S", OBConversion::OUTOPTIONS))
+        obErrorLog.ThrowError(__FUNCTION__, "No 2D or 3D coordinates exist. Any stereochemical information will"
+                   " be lost. To generate 2D or 3D coordinates use --gen2D or --gen3D.", obWarning, onceOnly);
+      else
+        obErrorLog.ThrowError(__FUNCTION__, "No 2D or 3D coordinates exist. Stereochemical information will"
+                   " be stored using an Open Babel extension. To generate 2D or 3D coordinates instead use --gen2D or --gen3D.", obWarning, onceOnly);
+    }
 
     PerceiveStereo(&mol);
 
@@ -761,6 +815,12 @@ namespace OpenBabel
       if (mol.GetDimension() == 3 || (mol.GetDimension()==2 && !pConv->IsOption("w", pConv->OUTOPTIONS)))
         TetStereoToWedgeHash(mol, updown, from);
 
+      // Calculate up/downness of cis/trans bonds for 0D
+      set<OBBond*> stereodbl;
+      if (mol.GetDimension() == 0 && !pConv->IsOption("S", OBConversion::OUTOPTIONS))
+        GetUpDown(mol, updown, stereodbl);
+      
+
       // The counts line:
       // aaabbblllfffcccsssxxxrrrpppiiimmmvvvvvv
       //
@@ -771,8 +831,31 @@ namespace OpenBabel
       // ... = obsolete
       // mmm = no longer supported (default=999)
       //                         aaabbblllfffcccsssxxxrrrpppiiimmmvvvvvv
+      bool chiralFlag = false;
+      int iflag = -1;
+      OBGenericData*  gd = mol.GetData("MOL Chiral Flag");
+      if (gd)
+      {
+        iflag = atoi(((OBPairData*) gd)->GetValue().c_str());
+        if (iflag == 0)
+          chiralFlag = false;
+        else if (iflag == 1)
+          chiralFlag = true;
+        else
+        {
+          stringstream errorMsg;
+          errorMsg << "WARNING: The Chiral Flag should be either 0 or 1. The value of "
+                                << iflag << " will be ignored.\n";	        
+    	    obErrorLog.ThrowError(__FUNCTION__, errorMsg.str() , obWarning);
+        }
+      }
+
+      if (iflag < 0 || iflag > 1)
+      {
+        chiralFlag = mol.IsChiral();
+      }
       snprintf(buff, BUFF_SIZE, "%3d%3d  0  0%3d  0  0  0  0  0999 V2000\n",
-               mol.NumAtoms(), mol.NumBonds(), mol.IsChiral());
+               mol.NumAtoms(), mol.NumBonds(), chiralFlag);
       ofs << buff;
 
       OBAtom *atom;
@@ -795,7 +878,7 @@ namespace OpenBabel
 
         int valence = 0; //Only non-zero when RAD value would be >=4 (outside spec)
         //or an unbonded metal
-        if(atom->GetSpinMultiplicity()>=4 || IsMetal(atom) && atom->GetValence()==0 )
+        if (atom->GetSpinMultiplicity()>=4 || (IsMetal(atom) && atom->GetValence()==0))
           valence = atom->GetValence()==0 ? 15 : atom->GetValence();
 
         snprintf(buff, BUFF_SIZE, "%10.4f%10.4f%10.4f %-3s%2d%3d%3d%3d%3d%3d%3d%3d%3d%3d%3d%3d",
@@ -943,7 +1026,7 @@ namespace OpenBabel
   //////////////////////////////////////////////////////
   bool MDLFormat::ReadV3000Block(istream& ifs, OBMol& mol, OBConversion* pConv,bool DoMany)
   {
-    bool ret;
+    bool ret = true;
     do
       {
         if(!ReadV3000Line(ifs,vs)) return false;
@@ -1321,6 +1404,93 @@ namespace OpenBabel
              ts->tm_hour, ts->tm_min);
     return string(td);
   }
+  
+  void MDLFormat::GetUpDown(OBMol& mol, map<OBBond*, OBStereo::BondDirection> &updown,
+                            set<OBBond*> &stereodbl)
+  {
+    // Create a set of unvisited CT stereos
+    OBStereoFacade facade(&mol);
+    std::set<OBCisTransStereo*> cistrans;
+    FOR_BONDBFS_OF_MOL(b, mol) // Probably no real advantage in the BFS part
+    {
+      if (b->GetBondOrder() != 2 || !facade.HasCisTransStereo(b->GetId())) continue;
+      OBCisTransStereo *ct = facade.GetCisTransStereo(b->GetId());
+      OBCisTransStereo::Config cfg = ct->GetConfig();
+      if (ct->GetConfig().specified)
+        cistrans.insert(ct);
+    }
+
+    // Initialise two opposite configurations for up/downness
+    bool use_alt_config;
+    vector<OBStereo::BondDirection> config(4), alt_config(4);
+    config[0] = OBStereo::UpBond;   config[3] = config[0];
+    config[1] = OBStereo::DownBond; config[2] = config[1];
+    alt_config[0] = config[1]; alt_config[3] = alt_config[0];
+    alt_config[1] = config[0]; alt_config[2] = alt_config[1];
+
+    // Initialize the stack
+    std::vector<OBCisTransStereo *> stack;
+
+    // Keep looping until all CT stereos have been handled
+    while (cistrans.size() > 0) {
+      stack.push_back( *(cistrans.begin()) );
+
+      // This loop uses the stack to handle a conjugated dbl bond system
+      while (stack.size() > 0) {
+        OBCisTransStereo *ct = stack.back();
+        stack.pop_back();
+        cistrans.erase(ct);
+        OBCisTransStereo::Config cfg = ct->GetConfig();
+
+        // ****************** START OF HANDLING ONE DOUBLE BOND ******************************
+        std::vector<OBBond *> refbonds(4, (OBBond*)NULL);
+        if (cfg.refs[0] != OBStereo::ImplicitRef) // Could be a hydrogen
+          refbonds[0] = mol.GetBond(mol.GetAtomById(cfg.refs[0]), mol.GetAtomById(cfg.begin));
+        if (cfg.refs[1] != OBStereo::ImplicitRef) // Could be a hydrogen
+          refbonds[1] = mol.GetBond(mol.GetAtomById(cfg.refs[1]), mol.GetAtomById(cfg.begin));
+              
+        if (cfg.refs[2] != OBStereo::ImplicitRef) // Could be a hydrogen
+          refbonds[2] = mol.GetBond(mol.GetAtomById(cfg.refs[2]), mol.GetAtomById(cfg.end));
+        if (cfg.refs[3] != OBStereo::ImplicitRef) // Could be a hydrogen
+          refbonds[3] = mol.GetBond(mol.GetAtomById(cfg.refs[3]), mol.GetAtomById(cfg.end));              
+              
+        // If any of the bonds have been previously set, now set them all
+        // in agreement
+        use_alt_config = false;
+        for (int i=0; i<4; ++i)
+          if (updown.find(refbonds[i]) != updown.end()) // We have already set this one (conjugated bond)
+            if (updown[refbonds[i]] != config[i])
+            {
+              use_alt_config = true;
+              break;
+            }
+              
+        // Set the configuration
+        OBBond* dbl_bond = mol.GetBond(mol.GetAtomById(cfg.begin), mol.GetAtomById(cfg.end));
+        stereodbl.insert(dbl_bond);
+        for(int i=0;i<4;i++)
+          if (refbonds[i] != NULL)
+            updown[refbonds[i]] = use_alt_config ? alt_config[i] : config[i];
+        // ******************** END OF HANDLING ONE DOUBLE BOND ******************************
+
+        // Find any conjugated CT stereos and put them on the stack
+        set<OBCisTransStereo*>::iterator ChiralSearch;
+        for (ChiralSearch = cistrans.begin(); ChiralSearch != cistrans.end(); ChiralSearch++)
+        {
+          // Are any of the refs of cfg on stereo double bonds?
+          OBCisTransStereo::Config cscfg = (*ChiralSearch)->GetConfig();
+          if (std::find(cfg.refs.begin(), cfg.refs.end(), cscfg.begin) != cfg.refs.end() ||
+              std::find(cfg.refs.begin(), cfg.refs.end(), cscfg.end)   != cfg.refs.end())
+          {
+            stack.push_back(*ChiralSearch);
+            //stack.insert(stack.begin(), *ChiralSearch);
+          }
+        }
+
+      } // Loop over stack
+    } // Loop over remaining CT stereos
+
+  }
 
   void MDLFormat::GetParity(OBMol& mol, map<OBAtom*, MDLFormat::Parity> &parity)
   {
@@ -1425,10 +1595,13 @@ namespace OpenBabel
     return n;
   }
 
-  void MDLFormat::ReadPropertyLines(istream& ifs, OBMol& mol)
+  bool MDLFormat::ReadPropertyLines(istream& ifs, OBMol& mol)
   {
     string line;
     while (std::getline(ifs, line)) {
+      if (line.substr(0, 4) == "$RXN")
+        return false; //Has read the first line of the next reaction in RXN format
+
       if (line.find("<") != string::npos) {
         size_t lt = line.find("<")+1;
         size_t rt = line.find_last_of(">");
@@ -1460,6 +1633,7 @@ namespace OpenBabel
       if (line.substr(0, 4) == "$MOL")
         break;
     }
+    return true;
   }
 
   bool MDLFormat::TestForAlias(const string& symbol, OBAtom* at, vector<pair<AliasData*,OBAtom*> >& aliases)
@@ -1483,4 +1657,73 @@ namespace OpenBabel
     return true;
   }
 
+  void MDLFormat::CisTransFromUpDown(OBMol *mol, std::map<OBBond*, OBStereo::BondDirection> *updown)
+  {
+    // Create a vector of CisTransStereo objects for the molecule
+
+    // Loop across the known cistrans bonds, updating them if necessary
+    std::vector<OBGenericData*>::iterator data;
+    std::vector<OBGenericData*> stereoData = mol->GetAllData(OBGenericDataType::StereoData);
+    for (data = stereoData.begin(); data != stereoData.end(); ++data) {
+      if (static_cast<OBStereoBase*>(*data)->GetType() != OBStereo::CisTrans)
+        continue;
+
+      OBCisTransStereo *ct = dynamic_cast<OBCisTransStereo*>(*data);
+      OBCisTransStereo::Config cfg = ct->GetConfig();
+      OBAtom *a1 = mol->GetAtomById(cfg.begin);
+      OBAtom *a2 = mol->GetAtomById(cfg.end);
+
+      OBBond* dbl_bond = mol->GetBond(a1, a2);
+
+      // Get the bonds of neighbors of atom1 and atom2
+      OBBond *a1_b1 = NULL, *a1_b2 = NULL, *a2_b1 = NULL, *a2_b2 = NULL;
+      OBStereo::BondDirection a1_stereo, a2_stereo;
+
+      FOR_BONDS_OF_ATOM(bi, a1) {
+        OBBond *b = &(*bi);
+        if (b == dbl_bond) continue;  // skip the double bond we're working on
+        if (a1_b1 == NULL && updown->find(b) != updown->end())
+        {
+          a1_b1 = b;    // remember a stereo bond of Atom1
+          a1_stereo = (*updown)[b];
+        }
+        else
+          a1_b2 = b;    // remember a 2nd bond of Atom1
+      }
+
+      FOR_BONDS_OF_ATOM(bi, a2) {
+        OBBond *b = &(*bi);
+        if (b == dbl_bond) continue;
+        if (a2_b1 == NULL && updown->find(b) != updown->end())
+        {
+          a2_b1 = b;    // remember a stereo bond of Atom2
+          a2_stereo = (*updown)[b];
+        }
+        else
+          a2_b2 = b;    // remember a 2nd bond of Atom2
+      }
+      
+      if (a1_b1 == NULL || a2_b1 == NULL) continue; // No cis/trans
+
+      cfg.specified = true;
+      
+      // a1_b2 and/or a2_b2 will be NULL if there are bonds to implicit hydrogens
+      unsigned int second = (a1_b2 == NULL) ? OBStereo::ImplicitRef : a1_b2->GetNbrAtom(a1)->GetId();
+      unsigned int fourth = (a2_b2 == NULL) ? OBStereo::ImplicitRef : a2_b2->GetNbrAtom(a2)->GetId();
+
+      // If a1_stereo==a2_stereo, this means cis for a1_b1 and a2_b1.
+      if (a1_stereo == a2_stereo)
+        cfg.refs = OBStereo::MakeRefs(a1_b1->GetNbrAtom(a1)->GetId(), second,
+                                      fourth, a2_b1->GetNbrAtom(a2)->GetId());
+      else
+        cfg.refs = OBStereo::MakeRefs(a1_b1->GetNbrAtom(a1)->GetId(), second,
+                                      a2_b1->GetNbrAtom(a2)->GetId(), fourth);
+      if (a1_stereo == OBStereo::UnknownDir || a2_stereo == OBStereo::UnknownDir)
+        cfg.specified = false;
+      // FIXME:: Handle specified unknown stereo on the dbl bond itself
+
+      ct->SetConfig(cfg);
+    }
+  } 
+
 }//namespace
