@@ -75,7 +75,7 @@ bool ThermoFormat::ReadMolecule(OBBase* pOb, OBConversion* pConv)
   //find line with 1 in col 80
   do
   {
-    if(!ifs.getline(ln,BUFF_SIZE) || stopOnEnd && !strncasecmp(ln,"END",3))
+    if (!ifs.getline(ln,BUFF_SIZE) || (stopOnEnd && !strncasecmp(ln,"END",3)))
       return false;
   }while(ln[79]!='1');
 
