@@ -4,7 +4,7 @@ titleformat.h - Displays and reads molecule titles
 Copyright (C) 2005 Chris Morley
 
 This file is part of the Open Babel project.
-For more information, see <http://openbabel.sourceforge.net/>
+For more information, see <http://openbabel.org/>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -31,9 +31,9 @@ public:
 
   virtual const char* Description() //required
   {
-      return
-"Title format\n \
-Displays and reads molecule titles\n";
+    return
+      "Title format\n"
+      "Displays and reads molecule titles\n";
   }
 	virtual unsigned int Flags() { return ZEROATOMSOK; }
 
@@ -61,7 +61,7 @@ bool TitleFormat::ReadMolecule(OBBase* pOb, OBConversion* pConv)
 	else
 		ifs >> title;
 
-	pmol->SetTitle(Trim(title));		
+	pmol->SetTitle(Trim(title));
 	return true;
 }
 
