@@ -632,13 +632,21 @@ namespace OpenBabel
               && (attrname=="xFract" || attrname=="yFract" || attrname=="zFract"))
               usingFract=true;
 
-            if(using3 && attrname=="x3" || using2 && attrname=="x2" || usingFract && attrname=="xFract")
+            if ((using3     && attrname=="x3") ||
+                (using2     && attrname=="x2") ||
+                (usingFract && attrname=="xFract")) {
               x=strtod(value.c_str(),NULL);
-            else if(using3 && attrname=="y3" || using2 && attrname=="y2" || usingFract && attrname=="yFract")
+            }
+            else if ((using3     && attrname=="y3") ||
+                     (using2     && attrname=="y2") ||
+                     (usingFract && attrname=="yFract")) {
               y=strtod(value.c_str(),NULL);
-            else if(using3 && attrname=="z3" || using2 && attrname=="z2" || usingFract && attrname=="zFract")
+            }
+            else if ((using3     && attrname=="z3") ||
+                     (using2     && attrname=="z2") ||
+                     (usingFract && attrname=="zFract")) {
               z=strtod(value.c_str(),NULL);
-
+            }
             else if(using2 && attrname=="xy2")
               {
                 vector<string> vals;
@@ -1937,7 +1945,7 @@ namespace OpenBabel
     map<int,char> acmap; //key=atom calss; value=last letter used as second in id
     OBAtomClassData* pac = static_cast<OBAtomClassData*>(mol.GetData("Atom Class"));
     atomIDs.push_back("Error"); //atom idex stats at 1. atomIDs[0] is not used
-    for (int idx=1; idx<=mol.NumAtoms(); ++idx)
+    for (unsigned int idx=1; idx<=mol.NumAtoms(); ++idx)
     {
       ss.str("");
       ss << 'a';
@@ -2155,7 +2163,7 @@ namespace OpenBabel
     //Energy is output when it is not zero
     //This is the molecular energy, probably originally in Hartrees,
     // stored in OB as kcal/mol, but output here in kJ/mol
-    if(mol.GetEnergy()<-1e-3)//will be negative if assigned
+    if(fabs(mol.GetEnergy()) > 1e-3)
       WriteScalarProperty(mol, "Energy", mol.GetEnergy() * CALSTOJOULES,
         "me:ZPE", "kJ/mol", "computational");
 
@@ -2287,7 +2295,7 @@ namespace OpenBabel
 
     double imaginaryFrequency = 0.0;
     //A negative frequency is output separately as an imaginary frequency (for transition states)
-    for(int i=0; i<vd->GetNumberOfFrequencies(); ++i)
+    for (unsigned int i=0; i<vd->GetNumberOfFrequencies(); ++i)
     {
       double freq = vd->GetFrequencies()[i];
       if(freq>0.0)
@@ -2322,7 +2330,7 @@ namespace OpenBabel
     xmlTextWriterStartElementNS(writer(), prefix, C_ARRAY, NULL);
     xmlTextWriterWriteFormatAttribute(writer(), C_UNITS,"%s","cm-1");
     const double WAVENUM_TO_GHZ=30.0;
-    for(int i=0; i<rd->GetRotConsts().size(); ++i)
+    for (unsigned int i=0; i<rd->GetRotConsts().size(); ++i)
       if(rd->GetRotConsts()[i]!=0.0)
         xmlTextWriterWriteFormatString(writer(),"%.3lf ", rd->GetRotConsts()[i]/WAVENUM_TO_GHZ);
     xmlTextWriterEndElement(writer());//array
