@@ -2,11 +2,11 @@
 Copyright (C) 2000 by OpenEye Scientific Software, Inc.
 Some portions Copyright (C) 2001-2006 by Geoffrey R. Hutchison
 Some portions Copyright (C) 2004 by Chris Morley
- 
+
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation version 2 of the License.
- 
+
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -35,15 +35,55 @@ namespace OpenBabel
     {
       return
         "XYZ cartesian coordinates format\n"
+"A generic coordinate format\n"
+"The \"XYZ\" chemical file format is widely supported by many programs, although no\n"
+"formal specification has been published. Consequently, Open Babel attempts to be\n"
+"extremely flexible in parsing XYZ format files. Similar formats include Tinker XYZ\n"
+"and UniChem XYZ which differ slightly in the format of the files. (Notably, UniChem XYZ\n"
+"uses the atomic number rather than element symbol for the first column.)\n\n"
+
+"* Line one of the file contains the number of atoms in the file.\n"
+"* Line two of the file contains a title, comment, or filename. \n\n"
+
+"Any remaining lines are parsed for atom information. Lines start with the element\n"
+"symbol, followed by X, Y, and Z coordinates in angstroms separated by whitespace.\n\n"
+
+"Multiple molecules / frames can be contained within one file.\n\n"
+
+"On **output**, the first line written is the number of atoms in the molecule\n"
+"(warning - the number of digits is limited to three for some programs,\n"
+"e.g. Maestro). Line two is the title of the molecule or the filename if\n"
+"no title is defined. Remaining lines define the atoms in the file. The\n"
+"first column is the atomic symbol (right-aligned on the third character),\n"
+"followed by the XYZ coordinates in \"10.5\" format, in angstroms. This means\n"
+"that all coordinates are printed with five decimal places.\n\n"
+
+"Example::\n\n"
+
+" 12\n"
+" benzene example\n"
+"   C        0.00000        1.40272        0.00000\n"
+"   H        0.00000        2.49029        0.00000\n"
+"   C       -1.21479        0.70136        0.00000\n"
+"   H       -2.15666        1.24515        0.00000\n"
+"   C       -1.21479       -0.70136        0.00000\n"
+"   H       -2.15666       -1.24515        0.00000\n"
+"   C        0.00000       -1.40272        0.00000\n"
+"   H        0.00000       -2.49029        0.00000\n"
+"   C        1.21479       -0.70136        0.00000\n"
+"   H        2.15666       -1.24515        0.00000\n"
+"   C        1.21479        0.70136        0.00000\n"
+"   H        2.15666        1.24515        0.00000\n\n"
+
         "Read Options e.g. -as\n"
         "  s  Output single bonds only\n"
         "  b  Disable bonding entirely\n\n";
     };
 
     virtual const char* SpecificationURL()
-    {return "http://openbabel.sourceforge.net/wiki/XYZ";}; //optional
+    {return "http://openbabel.org/wiki/XYZ";}; //optional
 
-    virtual const char* GetMIMEType() 
+    virtual const char* GetMIMEType()
     { return "chemical/x-xyz"; };
 
     //*** This section identical for most OBMol conversions ***
@@ -125,7 +165,7 @@ namespace OpenBabel
           {
             errorMsg << "Problems reading an XYZ file: "
                      << "Could not read line #" << i+2 << ", file error." << endl
-                     << " According to line one, there should be " << natoms 
+                     << " According to line one, there should be " << natoms
                      << " atoms, and therefore " << natoms+2 << " lines in the file.";
 
             obErrorLog.ThrowError(__FUNCTION__, errorMsg.str() , obWarning);
@@ -163,7 +203,7 @@ namespace OpenBabel
         }
 
         atom->SetAtomicNum(atomicNum);
-        if (atomicNum == 0) // still strange
+        if (atomicNum == 0) // still strange, try using an atom type
           atom->SetType(vs[0]);
 
         // Read the atom coordinates
@@ -205,10 +245,20 @@ namespace OpenBabel
             return(false);
           }
         atom->SetVector(x,y,z); //set coordinates
+
+        // OK, sometimes there's sym x y z charge -- accepted by Jmol
+        if (vs.size() > 5) {
+          string::size_type decimal = vs[4].find('.');
+          if (decimal !=string::npos) { // period found
+            double charge = strtod((char*)vs[4].c_str(),&endptr);
+            if (endptr != (char*)vs[4].c_str())
+              atom->SetPartialCharge(charge);
+          }
+        } // attempt to parse charges
       }
 
     // clean out any remaining blank lines
-    while(ifs.peek() != EOF && ifs.good() && 
+    while(ifs.peek() != EOF && ifs.good() &&
           (ifs.peek() == '\n' || ifs.peek() == '\r'))
       ifs.getline(buffer,BUFF_SIZE);
 
