@@ -31,6 +31,8 @@ GNU General Public License for more details.
 	#endif
 #endif
 
+// #define DONT_CATCH_EXCEPTIONS     // This is useful when debugging an exception
+
 #include <iosfwd>
 #include <fstream>
 #include <sstream>
@@ -510,7 +512,9 @@ namespace OpenBabel {
           rInpos = pInStream->tellg();
 
         bool ret=false;
-        try
+#ifndef DONT_CATCH_EXCEPTIONS
+       try
+#endif
           {
             ret = pInFormat->ReadChemObject(this);
 /*            if (ret && IsOption("readconformers", GENOPTIONS)) {
@@ -543,6 +547,7 @@ namespace OpenBabel {
 */
             SetFirstInput(false);
           }
+#ifndef DONT_CATCH_EXCEPTIONS
         catch(...)
           {
             if(!IsOption("e", GENOPTIONS) && !OneObjectOnly)
@@ -551,6 +556,7 @@ namespace OpenBabel {
               return Index; // the number we've actually output so far
             }
           }
+#endif
 
         if(!ret)
           {
@@ -1122,7 +1128,6 @@ namespace OpenBabel {
     //If infile == outfile issue error message and return false
     //If name without the extensions are the same issue warning and return true;
     //Otherwise return true
-    bool ret=true;
     string inname1, inname2;
     string::size_type pos;
     pos = infile.rfind('.');
@@ -1195,7 +1200,9 @@ namespace OpenBabel {
     ios_base::openmode omode =
       pOutFormat->Flags() & WRITEBINARY ? ios_base::out|ios_base::binary : ios_base::out;
     obErrorLog.ClearLog();
+#ifndef DONT_CATCH_EXCEPTIONS
     try
+#endif
       {
         ofstream ofs;
 
@@ -1422,11 +1429,13 @@ namespace OpenBabel {
           }
         return Count;
       }
+#ifndef DONT_CATCH_EXCEPTIONS
     catch(...)
       {
         obErrorLog.ThrowError(__FUNCTION__, "Conversion failed with an exception.",obError);
         return Count;
       }
+#endif
     return Count;
   }
 
