@@ -735,7 +735,7 @@ namespace OpenBabel
     tx = coordinates[_torsion[1]];
     ty = coordinates[_torsion[1]+1];
     tz = coordinates[_torsion[1]+2];
-    int i,j;
+    unsigned int i, j;
     for (i = 0; i < _rotatoms.size(); ++i)
       {
         j = _rotatoms[i];
@@ -815,7 +815,7 @@ namespace OpenBabel
     tx = c[_torsion[1]];
     ty = c[_torsion[1]+1];
     tz = c[_torsion[1]+2];
-    int i,j;
+    unsigned int i, j;
     for (i = 0; i < _rotatoms.size(); ++i)
       {
         j = _rotatoms[i];
@@ -941,7 +941,7 @@ namespace OpenBabel
         return;
       }
 
-    if (!vs.empty() && vs.size() > 5)
+    if (vs.size() > 5)
       {
         strncpy(temp_buffer,vs[0].c_str(), sizeof(temp_buffer) - 1);
         temp_buffer[sizeof(temp_buffer) - 1] = '\0';
