@@ -4,7 +4,7 @@ aromatest.cpp - Test Open Babel aromaticity perception
 Copyright (C) 2005-2006 Geoffrey R. Hutchison
  
 This file is part of the Open Babel project.
-For more information, see <http://openbabel.sourceforge.net/>
+For more information, see <http://openbabel.org/>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -36,22 +36,27 @@ extern "C" int strncasecmp(const char *s1, const char *s2, size_t n);
 using namespace std;
 using namespace OpenBabel;
 
-int main(int argc,char *argv[])
+int main()
 {
   // turn off slow sync with C-style output (we don't use it anyway).
   std::ios::sync_with_stdio(false);
 
-  if (argc != 2)
-    {
-      cout << "Usage: aromatest <file>" << endl;
-      cout << " Tests aromaticity perception -- all non-hydrogen atoms"
-           << "   are expected to be aromatic." << endl;
-      return(-1);
-    }
-
   cout << endl << "# Testing aromaticity perception...  " << endl;
-  
-  ifstream ifs(argv[1]);
+ 
+  #ifdef TESTDATADIR
+    string testdatadir(TESTDATADIR);
+    string filename = testdatadir + "aromatics.smi";
+  #else
+    string filename = "files/aromatics.smi";
+  #endif
+
+  #ifdef FORMATDIR
+    char env[BUFF_SIZE];
+    snprintf(env, BUFF_SIZE, "BABEL_LIBDIR=%s", FORMATDIR);
+    putenv(env);
+  #endif
+
+  ifstream ifs(filename.c_str());
   if (!ifs)
     {
       cout << "Bail out! Cannot read input file!" << endl;
@@ -61,7 +66,7 @@ int main(int argc,char *argv[])
   OBConversion conv(&ifs, &cout);
   OBFormat* pFormat;
   
-  pFormat = conv.FormatFromExt(argv[1]);
+  pFormat = conv.FormatFromExt("aromatics.smi");
   if ( pFormat == NULL )
     {
       cout << "Bail out! Cannot read file format!" << endl;
@@ -100,25 +105,7 @@ int main(int argc,char *argv[])
                    << " in molecule " << molCount << " "
                    << mol.GetTitle() << "\n";
             }
-        }
-
-      FOR_BONDS_OF_MOL(bond, mol)
-        {
-          if (bond->IsInRing() && !bond->IsAromatic())
-            {
-              cout << "not ok " << ++testCount << " # bond isn't aromatic!\n";
-              cout << "# begin atom " << bond->GetBeginAtomIdx()
-                   << " end atom " << bond->GetEndAtomIdx()
-                   << " bond order " << bond->GetBO();
-              cout << " in molecule " << molCount << " "
-                   << mol.GetTitle() << "\n";
-            }
-          else if (bond->IsInRing() && bond->IsAromatic())
-            {
-              cout << "ok " << ++testCount << "\n";
-            }
-        }
-	
+        }	
     } // while reading molecules
     
   // output the number of tests run
