@@ -2,7 +2,7 @@
 invalid-smiles.cpp - Test SMILES pattern parsing (rejecting invalid patterns)
 
 This file is part of the Open Babel project.
-For more information, see <http://openbabel.sourceforge.net/>
+For more information, see <http://openbabel.org/>
 
 Some portions Copyright (C) 2005-2006 Geoffrey R. Hutchison
  
@@ -26,12 +26,7 @@ GNU General Public License for more details.
 #include <openbabel/obconversion.h>
 
 #include <fstream>
-
-namespace OpenBabel
-{
-bool SafeOpen(std::ifstream &fs, const char *filename);
-bool SafeOpen(std::ofstream &fs, const char *filename);
-}
+#include <openbabel/obutil.h>
 
 using namespace std;
 using namespace OpenBabel;
@@ -56,6 +51,13 @@ int main(int argc,char *argv[])
   // turn off slow sync with C-style output (we don't use it anyway).
   std::ios::sync_with_stdio(false);
 
+  // Define location of file formats for testing
+  #ifdef FORMATDIR
+    char env[BUFF_SIZE];
+    snprintf(env, BUFF_SIZE, "BABEL_LIBDIR=%s", FORMATDIR);
+    putenv(env);
+  #endif
+
   if (argc != 1)
     {
       cout << "Usage: invalid-smiles" << endl;
