@@ -133,7 +133,7 @@ int main(int argc,char *argv[])
                   if(!*oext)
                     oext = argv[++arg]; //space left after -i: use next argument
 
-                  if (strncasecmp(oext, "MIME", 4) == 0)
+                  if (oext && strncasecmp(oext, "MIME", 4) == 0)
                     {
                       // get the MIME type from the next argument
                       oext = argv[++arg];
@@ -165,9 +165,9 @@ int main(int argc,char *argv[])
                     // param is a subtype, like babel -L ops gen3D
                     // or first arg is a plugin ID, like babel -L cml
                     OBPlugin* plugin;
-                    if(OBPlugin::GetPlugin("plugins", argv[arg+1])
-                      && (plugin = OBPlugin::GetPlugin(argv[arg+1], param))
-                      || (plugin = OBPlugin::GetPlugin(NULL, argv[arg+1])))
+                    if ((OBPlugin::GetPlugin("plugins", argv[arg+1]) &&
+                         (plugin = OBPlugin::GetPlugin(argv[arg+1], param))) ||
+                        (plugin = OBPlugin::GetPlugin(NULL, argv[arg+1])))
                     {
                       //Output details of subtype
                       string txt;
@@ -310,7 +310,7 @@ int main(int argc,char *argv[])
       if(FileList.empty())
         {
           cerr << "No input file or format spec or possibly a misplaced option.\n"
-            "Options, other than -i -o -O -m, must come after the input files.\n" <<endl;
+            "Most options must come after the input files. (-i -o -O -m can be anywhwere.)\n" <<endl;
           usage();
         }
     }
@@ -493,7 +493,7 @@ void help()
 *
 * \par OPTIONS
 *
-* If only input and ouput files are given, Open Babel will guess 
+* If only input and output files are given, Open Babel will guess 
 * the file type from the filename extension. \n\n
 *
 * \b -V :
